@@ -84,13 +84,14 @@ struct _EContactEditor
 	/* Whether an image is changed */
 	guint image_changed : 1;
 
+	/* Whether to try to reduce space used */
+	guint compress_ui : 1;
+
 	EList *writable_fields;
 
 	EList *required_fields;
 
-	/* ID for async load_source call */
-	guint  load_source_id;
-	EBook *load_book;
+	GCancellable *cancellable;
 
 	/* signal ids for "writable_status" */
 	gint target_editable_id;
