@@ -34,6 +34,9 @@
 #include "e-util/e-util-private.h"
 #include <glib/gi18n.h>
 
+/* backend-compatibility cruft */
+#include "e-util/gtk-compat.h"
+
 typedef struct dropdown_data dropdown_data;
 typedef enum {
 	E_CONTACT_MERGING_ADD,
@@ -49,9 +52,9 @@ typedef struct {
 	/*match is the duplicate contact already existing in the addressbook*/
 	EContact *match;
 	GList *avoid;
-	EBookIdCallback id_cb;
-	EBookCallback   cb;
-	EBookContactCallback c_cb;
+	EBookIdAsyncCallback id_cb;
+	EBookAsyncCallback   cb;
+	EBookContactAsyncCallback c_cb;
 	gpointer closure;
 } EContactMergingLookup;
 
@@ -110,12 +113,12 @@ free_lookup (EContactMergingLookup *lookup)
 }
 
 static void
-final_id_cb (EBook *book, EBookStatus status, const gchar *id, gpointer closure)
+final_id_cb (EBook *book, const GError *error, const gchar *id, gpointer closure)
 {
 	EContactMergingLookup *lookup = closure;
 
 	if (lookup->id_cb)
-		lookup->id_cb (lookup->book, status, id, lookup->closure);
+		lookup->id_cb (lookup->book, error, id, lookup->closure);
 
 	free_lookup (lookup);
 
@@ -123,12 +126,12 @@ final_id_cb (EBook *book, EBookStatus status, const gchar *id, gpointer closure)
 }
 
 static void
-final_cb_as_id (EBook *book, EBookStatus status, gpointer closure)
+final_cb_as_id (EBook *book, const GError *error, gpointer closure)
 {
 	EContactMergingLookup *lookup = closure;
 
 	if (lookup->id_cb)
-		lookup->id_cb (lookup->book, status, lookup->contact ? e_contact_get_const (lookup->contact, E_CONTACT_UID) : NULL, lookup->closure);
+		lookup->id_cb (lookup->book, error, lookup->contact ? e_contact_get_const (lookup->contact, E_CONTACT_UID) : NULL, lookup->closure);
 
 	free_lookup (lookup);
 
@@ -136,12 +139,12 @@ final_cb_as_id (EBook *book, EBookStatus status, gpointer closure)
 }
 
 static void
-final_cb (EBook *book, EBookStatus status, gpointer closure)
+final_cb (EBook *book, const GError *error, gpointer closure)
 {
 	EContactMergingLookup *lookup = closure;
 
 	if (lookup->cb)
-		lookup->cb (lookup->book, status, lookup->closure);
+		lookup->cb (lookup->book, error, lookup->closure);
 
 	free_lookup (lookup);
 
@@ -153,32 +156,39 @@ doit (EContactMergingLookup *lookup, gboolean force_commit)
 {
 	if (lookup->op == E_CONTACT_MERGING_ADD) {
 		if (force_commit)
-			e_book_async_commit_contact (lookup->book, lookup->contact, final_cb_as_id, lookup);
+			e_book_commit_contact_async (lookup->book, lookup->contact, final_cb_as_id, lookup);
 		else
-			e_book_async_add_contact (lookup->book, lookup->contact, final_id_cb, lookup);
+			e_book_add_contact_async (lookup->book, lookup->contact, final_id_cb, lookup);
 	} else if (lookup->op == E_CONTACT_MERGING_COMMIT)
-		e_book_async_commit_contact (lookup->book, lookup->contact, final_cb, lookup);
+		e_book_commit_contact_async (lookup->book, lookup->contact, final_cb, lookup);
 }
 
 static void
 cancelit (EContactMergingLookup *lookup)
 {
+	GError *error = g_error_new (E_BOOK_ERROR, E_BOOK_ERROR_CANCELLED, _("Cancelled"));
+
 	if (lookup->op == E_CONTACT_MERGING_ADD) {
-		final_id_cb (lookup->book, E_BOOK_ERROR_CANCELLED, NULL, lookup);
+		final_id_cb (lookup->book, error, NULL, lookup);
 	} else if (lookup->op == E_CONTACT_MERGING_COMMIT) {
-		final_cb (lookup->book, E_BOOK_ERROR_CANCELLED, lookup);
+		final_cb (lookup->book, error, lookup);
 	}
+
+	g_error_free (error);
 }
 
 static void
 dialog_map (GtkWidget *window, GdkEvent *event, GtkWidget *table)
 {
+	GtkAllocation allocation;
 	gint h, w;
 
+	gtk_widget_get_allocation (table, &allocation);
+
 	/* Spacing around the table */
-	w = table->allocation.width + 30;
+	w = allocation.width + 30;
 	/* buttons and outer spacing */
-	h = table->allocation.height + 60;
+	h = allocation.height + 60;
 	if (w > 400)
 		w = 400;
 	if (h > 450)
@@ -191,7 +201,7 @@ static void
 dropdown_changed (GtkWidget *dropdown, dropdown_data *data)
 {
 	gchar *str;
-	str = gtk_combo_box_get_active_text (GTK_COMBO_BOX (dropdown));
+	str = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (dropdown));
 
 	if (g_ascii_strcasecmp(str, ""))
 		e_contact_set (data->match, data->field, str);
@@ -204,6 +214,7 @@ static gint
 mergeit (EContactMergingLookup *lookup)
 {
 	GtkWidget *scrolled_window, *label, *hbox, *dropdown;
+	GtkWidget *content_area;
 	GtkDialog *dialog;
 	GtkTable *table;
 	EContactField field;
@@ -214,7 +225,9 @@ mergeit (EContactMergingLookup *lookup)
 	gint value = 0, result;
 
 	dialog = (GtkDialog *)(gtk_dialog_new_with_buttons (_("Merge Contact"), NULL, GTK_DIALOG_NO_SEPARATOR, NULL));
-	gtk_container_set_border_width (GTK_CONTAINER(dialog), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+
+	content_area = gtk_dialog_get_content_area (dialog);
 
 	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
@@ -256,7 +269,7 @@ mergeit (EContactMergingLookup *lookup)
 					break;
 				case 1:
 					/*New contact has email that is NOT equal to email in duplicate contact*/
-					if ((str && *str) && (g_ascii_strcasecmp(e_contact_get_const (lookup->match, E_CONTACT_EMAIL_1),str))) {
+					if ((str && *str) && (g_ascii_strcasecmp (e_contact_get_const (lookup->match, E_CONTACT_EMAIL_1),str))) {
 						use_field = E_CONTACT_EMAIL_2;
 						break;
 					}
@@ -265,8 +278,8 @@ mergeit (EContactMergingLookup *lookup)
 				case 2:
 					/*New contact has email and it is equal to neither of the 2 emails in the duplicate contact*/
 					if ((str && *str) &&
-							(g_ascii_strcasecmp(str,e_contact_get_const (lookup->match, E_CONTACT_EMAIL_1))) &&
-							(g_ascii_strcasecmp(e_contact_get_const (lookup->match, E_CONTACT_EMAIL_2),str))) {
+							(g_ascii_strcasecmp (str,e_contact_get_const (lookup->match, E_CONTACT_EMAIL_1))) &&
+							(g_ascii_strcasecmp (e_contact_get_const (lookup->match, E_CONTACT_EMAIL_2),str))) {
 						use_field = E_CONTACT_EMAIL_3;
 						break;
 					}
@@ -275,24 +288,24 @@ mergeit (EContactMergingLookup *lookup)
 				case 3:
 					/*New contact has email and it is equal to none of the 3 emails in the duplicate contact*/
 					if ((str && *str) &&
-							(g_ascii_strcasecmp(e_contact_get_const (lookup->match, E_CONTACT_EMAIL_1),str)) &&
-							(g_ascii_strcasecmp(e_contact_get_const (lookup->match, E_CONTACT_EMAIL_2),str)) &&
-							(g_ascii_strcasecmp(e_contact_get_const (lookup->match, E_CONTACT_EMAIL_3),str)))
+							(g_ascii_strcasecmp (e_contact_get_const (lookup->match, E_CONTACT_EMAIL_1),str)) &&
+							(g_ascii_strcasecmp (e_contact_get_const (lookup->match, E_CONTACT_EMAIL_2),str)) &&
+							(g_ascii_strcasecmp (e_contact_get_const (lookup->match, E_CONTACT_EMAIL_3),str)))
 						use_field = E_CONTACT_EMAIL_4;
 					else
 						continue;
 				}
 				label = gtk_label_new (_("Email"));
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX(hbox), (GtkWidget*)label, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*)label, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget *)hbox, 0, 1, row, row + 1);
 
-				dropdown = gtk_combo_box_new_text();
-				gtk_combo_box_append_text (GTK_COMBO_BOX (dropdown), string);
+				dropdown = gtk_combo_box_text_new ();
+				gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (dropdown), string);
 
 				data = g_new0 (dropdown_data, 1);
 
-				gtk_combo_box_append_text (GTK_COMBO_BOX (dropdown), "");
+				gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (dropdown), "");
 
 				gtk_combo_box_set_active (GTK_COMBO_BOX (dropdown), 0);
 				data->field = use_field;
@@ -301,41 +314,41 @@ mergeit (EContactMergingLookup *lookup)
 				g_signal_connect (dropdown, "changed", G_CALLBACK(dropdown_changed), data);
 
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX(hbox), (GtkWidget*)dropdown, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*)dropdown, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget *)hbox, 1, 2, row, row + 1);
 				gtk_widget_show ((GtkWidget *)dropdown);
 				continue;
 			}
-			if (((field == E_CONTACT_FULL_NAME) && (!g_ascii_strcasecmp(string, string1)))) {
+			if (((field == E_CONTACT_FULL_NAME) && (!g_ascii_strcasecmp (string, string1)))) {
 				row++;
-				label = gtk_label_new (e_contact_pretty_name(field));
+				label = gtk_label_new (e_contact_pretty_name (field));
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX(hbox), (GtkWidget*)label, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*)label, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget *)hbox, 0, 1, row, row + 1);
 
 				label = gtk_label_new (string);
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX(hbox), (GtkWidget*)label, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*)label, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget*)hbox, 1, 2, row, row + 1);
 				continue;
 			}
 
 			/*for all string fields except name and email*/
-			if (!(string1 && *string1) || (g_ascii_strcasecmp(string, string1))) {
+			if (!(string1 && *string1) || (g_ascii_strcasecmp (string, string1))) {
 				row++;
-				label = gtk_label_new (e_contact_pretty_name(field));
+				label = gtk_label_new (e_contact_pretty_name (field));
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX(hbox), (GtkWidget*)label, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*)label, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget *)hbox, 0, 1, row, row + 1);
 				data = g_new0 (dropdown_data, 1);
-				dropdown = gtk_combo_box_new_text();
-				gtk_combo_box_append_text (GTK_COMBO_BOX (dropdown), string);
+				dropdown = gtk_combo_box_text_new ();
+				gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (dropdown), string);
 				e_contact_set (lookup->match, field, string);
 
 				if (string1 && *string1)
-					gtk_combo_box_append_text (GTK_COMBO_BOX (dropdown), string1);
+					gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (dropdown), string1);
 				else
-					gtk_combo_box_append_text (GTK_COMBO_BOX (dropdown), "");
+					gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (dropdown), "");
 
 				gtk_combo_box_set_active (GTK_COMBO_BOX (dropdown), 0);
 				data->field = field;
@@ -346,7 +359,7 @@ mergeit (EContactMergingLookup *lookup)
 
 				g_signal_connect (dropdown, "changed", G_CALLBACK(dropdown_changed), data);
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX(hbox), (GtkWidget*)dropdown, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*)dropdown, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget *)hbox, 1, 2, row, row + 1);
 				gtk_widget_show_all ((GtkWidget *)dropdown);
 			}
@@ -355,7 +368,7 @@ mergeit (EContactMergingLookup *lookup)
 
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 420, 300);
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolled_window), GTK_WIDGET (table));
-	gtk_box_pack_start (GTK_BOX (dialog->vbox), GTK_WIDGET (scrolled_window), TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (content_area), GTK_WIDGET (scrolled_window), TRUE, TRUE, 0);
 	gtk_widget_show (scrolled_window);
 	g_signal_connect (dialog, "map-event", G_CALLBACK (dialog_map), table);
 	gtk_widget_show_all ((GtkWidget *)table);
@@ -365,8 +378,8 @@ mergeit (EContactMergingLookup *lookup)
 	{
 	case GTK_RESPONSE_OK:
 		     lookup->contact = lookup->match;
-		     e_book_async_remove_contact (lookup->book, lookup->match, NULL, lookup);
-		     e_book_async_add_contact (lookup->book, lookup->contact, final_id_cb, lookup);
+		     e_book_remove_contact_async (lookup->book, lookup->match, NULL, lookup);
+		     e_book_add_contact_async (lookup->book, lookup->contact, final_id_cb, lookup);
 		     value = 1;
 		     break;
 	case GTK_RESPONSE_CANCEL:
@@ -399,23 +412,23 @@ check_if_same (EContact *contact, EContact *match)
 			case 0:
 				return FALSE;
 			case 1:
-				if ((str && *str) && (g_ascii_strcasecmp(e_contact_get_const (match, E_CONTACT_EMAIL_1),str)))
+				if ((str && *str) && (g_ascii_strcasecmp (e_contact_get_const (match, E_CONTACT_EMAIL_1),str)))
 					return FALSE;
 			case 2:
-				if ((str && *str) && (g_ascii_strcasecmp(str,e_contact_get_const (match, E_CONTACT_EMAIL_1))) &&
-						(g_ascii_strcasecmp(e_contact_get_const (match, E_CONTACT_EMAIL_2),str)))
+				if ((str && *str) && (g_ascii_strcasecmp (str,e_contact_get_const (match, E_CONTACT_EMAIL_1))) &&
+						(g_ascii_strcasecmp (e_contact_get_const (match, E_CONTACT_EMAIL_2),str)))
 					return FALSE;
 			case 3:
-				if ((str && *str) && (g_ascii_strcasecmp(e_contact_get_const (match, E_CONTACT_EMAIL_1),str)) &&
-						(g_ascii_strcasecmp(e_contact_get_const (match, E_CONTACT_EMAIL_2),str)) &&
-						(g_ascii_strcasecmp(e_contact_get_const (match, E_CONTACT_EMAIL_3),str)))
+				if ((str && *str) && (g_ascii_strcasecmp (e_contact_get_const (match, E_CONTACT_EMAIL_1),str)) &&
+						(g_ascii_strcasecmp (e_contact_get_const (match, E_CONTACT_EMAIL_2),str)) &&
+						(g_ascii_strcasecmp (e_contact_get_const (match, E_CONTACT_EMAIL_3),str)))
 					return FALSE;
 			}
 		}
 		else {
 			string = (gchar *)e_contact_get_const (contact, field);
 			string1 = (gchar *)e_contact_get_const (match, field);
-			if ((string && *string) && (string1 && *string1) && (g_ascii_strcasecmp(string1,string)))
+			if ((string && *string) && (string1 && *string1) && (g_ascii_strcasecmp (string1,string)))
 				return FALSE;
 			/*if the field entry exist in either of the contacts,we'll have to give the choice and thus merge button should be sensitive*/
 			else if ((string && *string) && !(string1 && *string1))
@@ -460,7 +473,7 @@ match_query_callback (EContact *contact, EContact *match, EABContactMatchType ty
 
 	if (lookup->op == E_CONTACT_MERGING_FIND) {
 		if (lookup->c_cb)
-			lookup->c_cb (lookup->book, E_BOOK_ERROR_OK, (gint) type <= (gint) EAB_CONTACT_MATCH_VAGUE ? NULL : match, lookup->closure);
+			lookup->c_cb (lookup->book, NULL, (gint) type <= (gint) EAB_CONTACT_MATCH_VAGUE ? NULL : match, lookup->closure);
 
 		free_lookup (lookup);
 		finished_lookup ();
@@ -477,8 +490,9 @@ match_query_callback (EContact *contact, EContact *match, EABContactMatchType ty
 		doit (lookup, same_uids);
 	} else {
 		GtkBuilder *builder;
-
-		GtkWidget *widget, *merge_button;
+		GtkWidget *container;
+		GtkWidget *merge_button;
+		GtkWidget *widget;
 
 		/* XXX I think we're leaking the GtkBuilder. */
 		builder = gtk_builder_new ();
@@ -518,21 +532,26 @@ match_query_callback (EContact *contact, EContact *match, EABContactMatchType ty
 		widget = e_builder_get_widget (builder, "dialog-duplicate-contact");
 
 		gtk_widget_ensure_style (widget);
-		gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (widget)->vbox), 0);
-		gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (widget)->action_area), 12);
 
-		g_signal_connect (widget, "response",
-				  G_CALLBACK (response), lookup);
+		container = gtk_dialog_get_action_area (GTK_DIALOG (widget));
+		gtk_container_set_border_width (GTK_CONTAINER (container), 12);
+
+		container = gtk_dialog_get_content_area (GTK_DIALOG (widget));
+		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
+
+		g_signal_connect (
+			widget, "response",
+			G_CALLBACK (response), lookup);
 
 		gtk_widget_show_all (widget);
 	}
 }
 
 gboolean
-eab_merging_book_add_contact (EBook           *book,
-			      EContact        *contact,
-			      EBookIdCallback  cb,
-			      gpointer         closure)
+eab_merging_book_add_contact (EBook                *book,
+			      EContact             *contact,
+			      EBookIdAsyncCallback  cb,
+			      gpointer              closure)
 {
 	EContactMergingLookup *lookup;
 
@@ -552,10 +571,10 @@ eab_merging_book_add_contact (EBook           *book,
 }
 
 gboolean
-eab_merging_book_commit_contact (EBook                 *book,
-				 EContact              *contact,
-				 EBookCallback          cb,
-				 gpointer               closure)
+eab_merging_book_commit_contact (EBook              *book,
+				 EContact           *contact,
+				 EBookAsyncCallback  cb,
+				 gpointer            closure)
 {
 	EContactMergingLookup *lookup;
 
@@ -575,10 +594,10 @@ eab_merging_book_commit_contact (EBook                 *book,
 }
 
 gboolean
-eab_merging_book_find_contact (EBook                 *book,
-			       EContact              *contact,
-			       EBookContactCallback   cb,
-			       gpointer               closure)
+eab_merging_book_find_contact (EBook                     *book,
+			       EContact                  *contact,
+			       EBookContactAsyncCallback  cb,
+			       gpointer                   closure)
 {
 	EContactMergingLookup *lookup;
 
