@@ -40,7 +40,6 @@
 #include <e-util/e-dialog-utils.h>
 #include "common/authentication.h"
 #include "../e-timezone-entry.h"
-#include "../calendar-config.h"
 #include "comp-editor.h"
 #include "comp-editor-util.h"
 #include "e-send-options-utils.h"
@@ -55,6 +54,9 @@
 #include "../e-meeting-store.h"
 #include "../e-meeting-list-view.h"
 
+/* backward-compatibility cruft */
+#include "e-util/gtk-compat.h"
+
 #define TASK_PAGE_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), TYPE_TASK_PAGE, TaskPagePrivate))
@@ -483,8 +485,8 @@ get_current_account (TaskPage *page)
 	if (!str)
 		return NULL;
 
-	for (it = e_list_get_iterator((EList *)priv->accounts); e_iterator_is_valid(it); e_iterator_next(it)) {
-		EAccount *a = (EAccount *)e_iterator_get(it);
+	for (it = e_list_get_iterator ((EList *)priv->accounts); e_iterator_is_valid (it); e_iterator_next (it)) {
+		EAccount *a = (EAccount *)e_iterator_get (it);
 		gchar *full = g_strdup_printf("%s <%s>", a->id->name, a->id->address);
 
 		if (!g_ascii_strcasecmp (full, str)) {
@@ -585,7 +587,7 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 	e_cal_component_free_text_list (l);
 	e_buffer_tagger_update_tags (GTK_TEXT_VIEW (priv->description));
 
-	default_zone = calendar_config_get_icaltimezone ();
+	default_zone = comp_editor_get_timezone (editor);
 
 	/* Due Date. */
 	e_cal_component_get_due (comp, &d);
@@ -731,7 +733,7 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 
 				if (!priv->user_org) {
 					gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (priv->organizer))));
-					gtk_combo_box_append_text (GTK_COMBO_BOX (priv->organizer), string);
+					gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (priv->organizer), string);
 					gtk_combo_box_set_active (GTK_COMBO_BOX (priv->organizer), 0);
 					gtk_editable_set_editable (GTK_EDITABLE (gtk_bin_get_child (GTK_BIN (priv->organizer))), FALSE);
 				} else {
@@ -935,8 +937,10 @@ task_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 	e_cal_component_set_classification (comp, classification);
 
 	/* send options */
-	if (priv->sendoptions_shown && priv->sod)
-		e_send_options_utils_fill_component (priv->sod, comp);
+	if (priv->sendoptions_shown && priv->sod) {
+		icaltimezone *zone = comp_editor_get_timezone (editor);
+		e_send_options_utils_fill_component (priv->sod, comp, zone);
+	}
 
 	/* Categories */
 	cat = e_dialog_editable_get (priv->categories);
@@ -1184,7 +1188,7 @@ remove_clicked_cb (GtkButton *btn, TaskPage *page)
 	for (tmp = paths; tmp; tmp=tmp->next) {
 		path = tmp->data;
 
-		gtk_tree_model_get_iter (GTK_TREE_MODEL(priv->model), &iter, path);
+		gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->model), &iter, path);
 
 		gtk_tree_model_get (GTK_TREE_MODEL (priv->model), &iter, E_MEETING_STORE_ADDRESS_COL, &address, -1);
 		ia = e_meeting_store_find_attendee (priv->model, address, NULL);
@@ -1288,12 +1292,12 @@ list_view_event (EMeetingListView *list_view, GdkEvent *event, TaskPage *page) {
 static gboolean
 list_key_press (EMeetingListView *list_view, GdkEventKey *event, TaskPage *page)
 {
-	if (event->keyval == GDK_Delete) {
+	if (event->keyval == GDK_KEY_Delete) {
 
 		remove_clicked_cb (NULL, page);
 
 		return TRUE;
-	} else if (event->keyval == GDK_Insert) {
+	} else if (event->keyval == GDK_KEY_Insert) {
 		add_clicked_cb (NULL, page);
 
 		return TRUE;
@@ -1357,7 +1361,7 @@ task_page_set_info_string (TaskPage *tpage, const gchar *icon, const gchar *msg)
 	priv = tpage->priv;
 
 	gtk_image_set_from_stock (GTK_IMAGE (priv->info_icon), icon, GTK_ICON_SIZE_BUTTON);
-	gtk_label_set_markup (GTK_LABEL(priv->info_string), msg);
+	gtk_label_set_markup (GTK_LABEL (priv->info_string), msg);
 
 	if (msg && icon)
 		gtk_widget_show (priv->info_hbox);
@@ -1417,7 +1421,7 @@ get_widgets (TaskPage *tpage)
 
 	priv->organizer = e_builder_get_widget (priv->builder, "organizer");
 	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (priv->organizer))));
-	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (priv->organizer), 0);
+	gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX_ENTRY (priv->organizer), 0);
 
 	priv->invite = e_builder_get_widget (priv->builder, "invite");
 	priv->add = e_builder_get_widget (priv->builder, "add-attendee");
@@ -1489,8 +1493,8 @@ date_changed_cb (EDateEdit *dedit,
 	CompEditorPageDates dates;
 	gboolean date_set, time_set;
 	ECalComponentDateTime start_dt, due_dt;
-	struct icaltimetype start_tt = icaltime_null_time();
-	struct icaltimetype due_tt = icaltime_null_time();
+	struct icaltimetype start_tt = icaltime_null_time ();
+	struct icaltimetype due_tt = icaltime_null_time ();
 
 	if (comp_editor_page_get_updating (COMP_EDITOR_PAGE (tpage)))
 		return;
@@ -1624,8 +1628,8 @@ static void
 times_updated (TaskPage *tpage, gboolean adjust_end_time)
 {
 	TaskPagePrivate *priv;
-	struct icaltimetype start_tt = icaltime_null_time();
-	struct icaltimetype end_tt = icaltime_null_time();
+	struct icaltimetype start_tt = icaltime_null_time ();
+	struct icaltimetype end_tt = icaltime_null_time ();
 	gboolean date_set;
 	gboolean set_start_date = FALSE, set_end_date = FALSE, adjust_by_hour;
 	icaltimezone *zone;
@@ -1723,7 +1727,7 @@ source_changed_cb (ESourceComboBox *source_combo_box, TaskPage *tpage)
 	if (client) {
 		icaltimezone *zone;
 
-		zone = calendar_config_get_icaltimezone ();
+		zone = comp_editor_get_timezone (editor);
 		e_cal_set_default_timezone (client, zone, NULL);
 	}
 
@@ -1756,7 +1760,7 @@ source_changed_cb (ESourceComboBox *source_combo_box, TaskPage *tpage)
 		if (client) {
 			gchar *backend_addr = NULL;
 
-			e_cal_get_cal_address(client, &backend_addr, NULL);
+			e_cal_get_cal_address (client, &backend_addr, NULL);
 
 			if (priv->is_assignment)
 				task_page_select_organizer (tpage, backend_addr);
@@ -1839,12 +1843,16 @@ init_widgets (TaskPage *tpage)
 
 	/* Make sure the EDateEdit widgets use our timezones to get the
 	   current time. */
-	e_date_edit_set_get_time_callback (E_DATE_EDIT (priv->start_date),
-					   (EDateEditGetTimeCallback) comp_editor_get_current_time,
-					   tpage, NULL);
-	e_date_edit_set_get_time_callback (E_DATE_EDIT (priv->due_date),
-					   (EDateEditGetTimeCallback) comp_editor_get_current_time,
-					   tpage, NULL);
+	e_date_edit_set_get_time_callback (
+		E_DATE_EDIT (priv->start_date),
+		(EDateEditGetTimeCallback) comp_editor_get_current_time,
+		g_object_ref (editor),
+		(GDestroyNotify) g_object_unref);
+	e_date_edit_set_get_time_callback (
+		E_DATE_EDIT (priv->due_date),
+		(EDateEditGetTimeCallback) comp_editor_get_current_time,
+		g_object_ref (editor),
+		(GDestroyNotify) g_object_unref);
 
 	/* Generic informative messages */
 	gtk_widget_hide (priv->info_hbox);
@@ -1928,7 +1936,7 @@ init_widgets (TaskPage *tpage)
 	g_signal_connect (priv->list_view, "attendee_added", G_CALLBACK (attendee_added_cb), tpage);
 
 	/* Set the default timezone, so the timezone entry may be hidden. */
-	zone = calendar_config_get_icaltimezone ();
+	zone = comp_editor_get_timezone (editor);
 	e_timezone_entry_set_default_timezone (E_TIMEZONE_ENTRY (priv->timezone), zone);
 
 	action = comp_editor_get_action (editor, "view-time-zone");
@@ -1984,7 +1992,7 @@ task_page_select_organizer (TaskPage *tpage, const gchar *backend_address)
 	editor = comp_editor_page_get_editor (COMP_EDITOR_PAGE (tpage));
 	client = comp_editor_get_client (editor);
 
-	def_account = itip_addresses_get_default();
+	def_account = itip_addresses_get_default ();
 	if (def_account && def_account->enabled)
 		def_address = g_strdup_printf("%s <%s>", def_account->id->name, def_account->id->address);
 
@@ -2061,12 +2069,12 @@ task_page_construct (TaskPage *tpage, EMeetingStore *model, ECal *client)
 	}
 
 	priv->accounts = itip_addresses_get ();
-	for (it = e_list_get_iterator((EList *)priv->accounts);
-	     e_iterator_is_valid(it);
-	     e_iterator_next(it)) {
+	for (it = e_list_get_iterator ((EList *)priv->accounts);
+	     e_iterator_is_valid (it);
+	     e_iterator_next (it)) {
 		gchar *full = NULL;
 
-		a = (EAccount *)e_iterator_get(it);
+		a = (EAccount *)e_iterator_get (it);
 
 		/* skip disabled accounts */
 		if (!a->enabled)
@@ -2074,16 +2082,16 @@ task_page_construct (TaskPage *tpage, EMeetingStore *model, ECal *client)
 
 		full = g_strdup_printf("%s <%s>", a->id->name, a->id->address);
 
-		priv->address_strings = g_list_append(priv->address_strings, full);
+		priv->address_strings = g_list_append (priv->address_strings, full);
 	}
 
-	g_object_unref(it);
+	g_object_unref (it);
 
 	if (priv->address_strings) {
 		GList *l;
 
 		for (l = priv->address_strings; l; l = l->next)
-			gtk_combo_box_append_text (GTK_COMBO_BOX (priv->organizer), l->data);
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (priv->organizer), l->data);
 
 		gtk_combo_box_set_active (GTK_COMBO_BOX (priv->organizer), 0);
 
