@@ -34,7 +34,6 @@
 #include <libecal/e-cal-time-util.h>
 #include <libedataserver/e-data-server-util.h>
 #include <libedataserver/e-categories.h>
-#include "calendar-config.h"
 #include "e-calendar-view.h"
 #include "e-day-view-top-item.h"
 
@@ -76,8 +75,6 @@ day_view_top_item_draw_triangle (EDayViewTopItem *top_item,
 	gint c1, c2;
 	cairo_t *cr;
 
-	cr = gdk_cairo_create (drawable);
-
 	day_view = e_day_view_top_item_get_day_view (top_item);
 
 	points[0].x = x;
@@ -102,6 +99,8 @@ day_view_top_item_draw_triangle (EDayViewTopItem *top_item,
 	if (!is_comp_data_valid (event))
 		return;
 
+	cr = gdk_cairo_create (drawable);
+
 	cairo_save (cr);
 	/* Fill it in. */
 	if (gdk_color_parse (
@@ -157,7 +156,6 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 	EDayView *day_view;
 	EDayViewEvent *event;
 	GtkStyle *style;
-	GdkGC *gc, *fg_gc;
 	gint start_day, end_day;
 	gint item_x, item_y, item_w, item_h;
 	gint text_x, icon_x, icon_y, icon_x_inc;
@@ -168,7 +166,6 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 	gint min_end_time_x, suffix_width, max_icon_x;
 	const gchar *suffix;
 	gboolean draw_start_triangle, draw_end_triangle;
-	GdkRectangle clip_rect;
 	GSList *categories_list, *elem;
 	PangoLayout *layout;
 	GdkColor bg_color;
@@ -176,18 +173,11 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 	cairo_pattern_t *pat;
 	guint16 red, green, blue;
 	gdouble cc = 65535.0;
-	gboolean gradient;
-	gfloat alpha;
 	gdouble x0, y0, rect_height, rect_width, radius;
 
 	day_view = e_day_view_top_item_get_day_view (top_item);
 	model = e_calendar_view_get_model (E_CALENDAR_VIEW (day_view));
 
-	cr = gdk_cairo_create (drawable);
-
-	gradient = calendar_config_get_display_events_gradient ();
-	alpha = calendar_config_get_display_events_alpha ();
-
 	/* If the event is currently being dragged, don't draw it. It will
 	   be drawn in the special drag items. */
 	if (day_view->drag_event_day == E_DAY_VIEW_LONG_EVENT
@@ -209,9 +199,9 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 	if (!is_comp_data_valid (event))
 		return;
 
+	cr = gdk_cairo_create (drawable);
+
 	style = gtk_widget_get_style (GTK_WIDGET (day_view));
-	gc = day_view->main_gc;
-	fg_gc = style->fg_gc[GTK_STATE_NORMAL];
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (
 		comp, icalcomponent_new_clone (event->comp_data->icalcomp));
@@ -249,7 +239,7 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 
 	draw_curved_rectangle (cr, x0, y0, rect_width, rect_height, radius);
 
-	cairo_set_source_rgba (cr, 1, 1, 1, alpha);
+	cairo_set_source_rgba (cr, 1, 1, 1, 1.0);
 	cairo_fill_preserve (cr);
 
 	cairo_restore (cr);
@@ -284,18 +274,14 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 
 	draw_curved_rectangle (cr, x0, y0, rect_width, rect_height, radius);
 
-	if (gradient) {
-		pat = cairo_pattern_create_linear (item_x - x + 5.5, item_y + 2.5 - y,
-						item_x - x + 5, item_y - y + item_h + 7.5);
-		cairo_pattern_add_color_stop_rgba (pat, 1, red/cc, green/cc, blue/cc, 0.8);
-		cairo_pattern_add_color_stop_rgba (pat, 0, red/cc, green/cc, blue/cc, 0.4);
-		cairo_set_source (cr, pat);
-		cairo_fill_preserve (cr);
-		cairo_pattern_destroy (pat);
-	} else {
-		cairo_set_source_rgba (cr, red/cc, green/cc, blue/cc, 0.8);
-		cairo_fill_preserve (cr);
-	}
+	pat = cairo_pattern_create_linear (item_x - x + 5.5, item_y + 2.5 - y,
+					item_x - x + 5, item_y - y + item_h + 7.5);
+	cairo_pattern_add_color_stop_rgba (pat, 1, red/cc, green/cc, blue/cc, 0.8);
+	cairo_pattern_add_color_stop_rgba (pat, 0, red/cc, green/cc, blue/cc, 0.4);
+	cairo_set_source (cr, pat);
+	cairo_fill_preserve (cr);
+	cairo_pattern_destroy (pat);
+
 	cairo_set_source_rgba (cr, red/cc, green/cc, blue/cc, 0);
 	cairo_set_line_width (cr, 0.5);
 	cairo_stroke (cr);
@@ -350,6 +336,8 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 
 	time_width = e_day_view_get_time_string_width (day_view);
 
+        gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_NORMAL]);
+
 	if (event->start > day_view->day_starts[start_day]) {
 		offset = day_view->first_hour_shown * 60
 			+ day_view->first_minute_shown + event->start_minute;
@@ -368,25 +356,26 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 				    display_hour, minute, suffix);
 		}
 
-		clip_rect.x = item_x - x;
-		clip_rect.y = item_y - y;
-		clip_rect.width = item_w - E_DAY_VIEW_LONG_EVENT_BORDER_WIDTH;
-		clip_rect.height = item_h;
-		gdk_gc_set_clip_rectangle (fg_gc, &clip_rect);
+                cairo_save (cr);
+
+                cairo_rectangle (cr,
+                                 item_x - x, item_y - y,
+				 item_w - E_DAY_VIEW_LONG_EVENT_BORDER_WIDTH, item_h);
+                cairo_clip (cr);
 
 		time_x = item_x + E_DAY_VIEW_LONG_EVENT_X_PAD - x;
 		if (display_hour < 10)
 			time_x += day_view->digit_width;
 
 		layout = gtk_widget_create_pango_layout (GTK_WIDGET (day_view), buffer);
-		gdk_draw_layout (drawable, fg_gc,
-				 time_x,
-				 item_y + E_DAY_VIEW_LONG_EVENT_BORDER_HEIGHT +
-				 E_DAY_VIEW_LONG_EVENT_Y_PAD - y,
-				 layout);
+                cairo_move_to (cr,
+                               time_x,
+                               item_y + E_DAY_VIEW_LONG_EVENT_BORDER_HEIGHT +
+                               E_DAY_VIEW_LONG_EVENT_Y_PAD - y);
+                pango_cairo_show_layout (cr, layout);
 		g_object_unref (layout);
 
-		gdk_gc_set_clip_rectangle (fg_gc, NULL);
+		cairo_restore (cr);
 
 		min_end_time_x += time_width
 			+ E_DAY_VIEW_LONG_EVENT_TIME_X_PAD;
@@ -424,10 +413,10 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 				time_x += day_view->digit_width;
 
 			layout = gtk_widget_create_pango_layout (GTK_WIDGET (day_view), buffer);
-			gdk_draw_layout (drawable, fg_gc,
-					 time_x,
-					 item_y + E_DAY_VIEW_LONG_EVENT_Y_PAD + 1 - y,
-					 layout);
+                        cairo_move_to (cr,
+                                       time_x,
+                                       item_y + E_DAY_VIEW_LONG_EVENT_Y_PAD + 1 - y);
+			pango_cairo_show_layout (cr, layout);
 			g_object_unref (layout);
 
 			max_icon_x -= time_width + E_DAY_VIEW_LONG_EVENT_TIME_X_PAD;
@@ -495,13 +484,13 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 			continue;
 
 		if (icon_x <= max_icon_x) {
-			gdk_gc_set_clip_origin (gc, icon_x, icon_y);
-			gdk_draw_pixbuf (drawable, gc,
-					 pixbuf,
-					 0, 0, icon_x, icon_y,
+			gdk_cairo_set_source_pixbuf (cr, pixbuf,
+                                                     icon_x, icon_y);
+                        cairo_rectangle (cr,
+                                         icon_x, icon_y,
 					 E_DAY_VIEW_ICON_WIDTH,
-					 E_DAY_VIEW_ICON_HEIGHT,
-					 GDK_RGB_DITHER_NORMAL, 0, 0);
+					 E_DAY_VIEW_ICON_HEIGHT);
+                        cairo_fill (cr);
 			icon_x -= icon_x_inc;
 		}
 	}
@@ -509,7 +498,6 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 	e_cal_component_free_categories_list (categories_list);
 	g_object_unref (comp);
 	cairo_destroy (cr);
-	gdk_gc_set_clip_mask (gc, NULL);
 }
 
 static void
@@ -576,15 +564,14 @@ day_view_top_item_dispose (GObject *object)
 
 static void
 day_view_top_item_update (GnomeCanvasItem *item,
-                          gdouble *affine,
-                          ArtSVP *clip_path,
+                          const cairo_matrix_t *i2c,
                           gint flags)
 {
 	GnomeCanvasItemClass *canvas_item_class;
 
 	/* Chain up to parent's update() method. */
 	canvas_item_class = GNOME_CANVAS_ITEM_CLASS (parent_class);
-	canvas_item_class->update (item, affine, clip_path, flags);
+	canvas_item_class->update (item, i2c, flags);
 
 	/* The item covers the entire canvas area. */
 	item->x1 = 0;
@@ -604,7 +591,6 @@ day_view_top_item_draw (GnomeCanvasItem *canvas_item,
 	EDayViewTopItem *top_item;
 	EDayView *day_view;
 	GtkStyle *style;
-	GdkGC *fg_gc;
 	gchar buffer[128];
 	GtkAllocation allocation;
 	GdkRectangle clip_rect;
@@ -623,7 +609,6 @@ day_view_top_item_draw (GnomeCanvasItem *canvas_item,
 	cr = gdk_cairo_create (drawable);
 
 	style = gtk_widget_get_style (GTK_WIDGET (day_view));
-	fg_gc = style->fg_gc[GTK_STATE_NORMAL];
 	gtk_widget_get_allocation (
 		GTK_WIDGET (canvas_item->canvas), &allocation);
 	canvas_width = allocation.width;
@@ -721,19 +706,21 @@ day_view_top_item_draw (GnomeCanvasItem *canvas_item,
 				clip_rect.width = day_view->day_widths[day];
 			clip_rect.height = item_height - 2;
 
-			gdk_gc_set_clip_rectangle (fg_gc, &clip_rect);
+                        cairo_save (cr);
+
+                        gdk_cairo_rectangle (cr, &clip_rect);
+                        cairo_clip (cr);
 
 			layout = gtk_widget_create_pango_layout (GTK_WIDGET (day_view), buffer);
 			pango_layout_get_pixel_size (layout, &date_width, NULL);
 			date_x = day_view->day_offsets[day] + (clip_rect.width - date_width) / 2;
 
-			gdk_draw_layout (drawable, fg_gc,
-					 date_x - x,
-					 3 - y,
-					 layout);
-			g_object_unref (layout);
+                        gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_NORMAL]);
+                        cairo_move_to (cr, date_x - x, 3 - y);
+                        pango_cairo_show_layout (cr, layout);
 
-			gdk_gc_set_clip_rectangle (fg_gc, NULL);
+			g_object_unref (layout);
+                        cairo_restore (cr);
 
 			/* Draw the lines down the left and right of the date cols. */
 			if (day != 0) {
@@ -781,21 +768,14 @@ day_view_top_item_draw (GnomeCanvasItem *canvas_item,
 	cairo_destroy (cr);
 }
 
-static double
+static GnomeCanvasItem *
 day_view_top_item_point (GnomeCanvasItem *item,
                          gdouble x,
                          gdouble y,
                          gint cx,
-                         gint cy,
-                         GnomeCanvasItem **actual_item)
+                         gint cy)
 {
-	/* This is supposed to return the nearest item the the point
-	 * and the distance.  Since we are the only item we just return
-	 * ourself and 0 for the distance.  This is needed so that we
-	 * get button/motion events. */
-	*actual_item = item;
-
-	return 0.0;
+	return item;
 }
 
 static void
