@@ -75,7 +75,9 @@ struct _EMailPanedViewPrivate {
 
 enum {
 	PROP_0,
-	PROP_GROUP_BY_THREADS
+	PROP_FORWARD_STYLE,
+	PROP_GROUP_BY_THREADS,
+	PROP_REPLY_STYLE
 };
 
 #define STATE_KEY_GROUP_BY_THREADS	"GroupByThreads"
@@ -260,11 +262,23 @@ mail_paned_view_set_property (GObject *object,
                               GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_FORWARD_STYLE:
+			e_mail_reader_set_forward_style (
+				E_MAIL_READER (object),
+				g_value_get_enum (value));
+			return;
+
 		case PROP_GROUP_BY_THREADS:
 			e_mail_reader_set_group_by_threads (
 				E_MAIL_READER (object),
 				g_value_get_boolean (value));
 			return;
+
+		case PROP_REPLY_STYLE:
+			e_mail_reader_set_reply_style (
+				E_MAIL_READER (object),
+				g_value_get_enum (value));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -277,12 +291,26 @@ mail_paned_view_get_property (GObject *object,
                               GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_FORWARD_STYLE:
+			g_value_set_enum (
+				value,
+				e_mail_reader_get_forward_style (
+				E_MAIL_READER (object)));
+			return;
+
 		case PROP_GROUP_BY_THREADS:
 			g_value_set_boolean (
 				value,
 				e_mail_reader_get_group_by_threads (
 				E_MAIL_READER (object)));
 			return;
+
+		case PROP_REPLY_STYLE:
+			g_value_set_enum (
+				value,
+				e_mail_reader_get_reply_style (
+				E_MAIL_READER (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -343,6 +371,20 @@ mail_paned_view_get_action_group (EMailReader *reader)
 	return E_SHELL_WINDOW_ACTION_GROUP_MAIL (shell_window);
 }
 
+static EAlertSink *
+mail_paned_view_get_alert_sink (EMailReader *reader)
+{
+	EMailView *view;
+	EShellView *shell_view;
+	EShellContent *shell_content;
+
+	view = E_MAIL_VIEW (reader);
+	shell_view = e_mail_view_get_shell_view (view);
+	shell_content = e_shell_view_get_shell_content (shell_view);
+
+	return E_ALERT_SINK (shell_content);
+}
+
 static EMailBackend *
 mail_paned_view_get_backend (EMailReader *reader)
 {
@@ -892,17 +934,30 @@ e_mail_paned_view_class_init (EMailPanedViewClass *class)
 
 	class->open_selected_mail = mail_paned_view_open_selected_mail;
 
+	/* Inherited from EMailReader */
+	g_object_class_override_property (
+		object_class,
+		PROP_FORWARD_STYLE,
+		"forward-style");
+
 	/* Inherited from EMailReader */
 	g_object_class_override_property (
 		object_class,
 		PROP_GROUP_BY_THREADS,
 		"group-by-threads");
+
+	/* Inherited from EMailReader */
+	g_object_class_override_property (
+		object_class,
+		PROP_REPLY_STYLE,
+		"reply-style");
 }
 
 static void
 e_mail_paned_view_reader_init (EMailReaderInterface *interface)
 {
 	interface->get_action_group = mail_paned_view_get_action_group;
+	interface->get_alert_sink = mail_paned_view_get_alert_sink;
 	interface->get_backend = mail_paned_view_get_backend;
 	interface->get_formatter = mail_paned_view_get_formatter;
 	interface->get_hide_deleted = mail_paned_view_get_hide_deleted;
