@@ -32,11 +32,6 @@ G_BEGIN_DECLS
 #include <mail/mail-mt.h>
 #include <mail/e-mail-session.h>
 
-void mail_append_mail (CamelFolder *folder, CamelMimeMessage *message, CamelMessageInfo *info,
-		       void (*done)(CamelFolder *folder, CamelMimeMessage *msg, CamelMessageInfo *info, gint ok,
-				    const gchar *appended_uid, gpointer data),
-		       gpointer data);
-
 void		mail_transfer_messages		(EMailSession *session,
 						 CamelFolder *source,
 						 GPtrArray *uids,
@@ -52,11 +47,6 @@ gint mail_get_message (CamelFolder *folder, const gchar *uid,
 		       gpointer data,
 		       MailMsgDispatchFunc dispatch);
 
-gint
-mail_get_messagex (CamelFolder *folder, const gchar *uid,
-		  void (*done) (CamelFolder *folder, const gchar *uid, CamelMimeMessage *msg, gpointer data, GError **error),
-		  gpointer data, MailMsgDispatchFunc dispatch);
-
 /* get several messages */
 gint mail_get_messages (CamelFolder *folder, GPtrArray *uids,
 			void (*done) (CamelFolder *folder, GPtrArray *uids, GPtrArray *msgs, gpointer data),
@@ -99,7 +89,7 @@ void mail_refresh_folder (CamelFolder *folder,
 			  void (*done) (CamelFolder *folder, gpointer data),
 			  gpointer data);
 
-void mail_expunge_folder (CamelFolder *folder,
+void mail_expunge_folder (EMailSession *session, CamelFolder *folder,
 			  void (*done) (CamelFolder *folder, gpointer data),
 			  gpointer data);
 
@@ -162,14 +152,6 @@ void		mail_filter_folder		(EMailSession *session,
 						 gboolean notify);
 
 /* Work Offline */
-void		mail_prep_offline		(EMailSession *session,
-						 const gchar *uri,
-						 CamelOperation *cancel,
-						 void (*done)(const gchar *, gpointer data),
-						 gpointer data);
-gint mail_store_set_offline (CamelStore *store, gboolean offline,
-			   void (*done)(CamelStore *, gpointer data),
-			   gpointer data);
 gint mail_store_prepare_offline (CamelStore *store);
 
 /* filter driver execute shell command async callback */
@@ -181,6 +163,8 @@ gint		mail_check_service		(EMailSession *session,
 						 void (*done)(const gchar *url, CamelProviderType type, GList *authtypes, gpointer data),
 						 gpointer data);
 
+gint mail_disconnect_store (CamelStore *store);
+
 G_END_DECLS
 
 #endif /* MAIL_OPS_H */
