@@ -336,30 +336,32 @@ mark_all_as_read (CamelFolder *folder)
 	gint i;
 
 	uids =  camel_folder_get_uids (folder);
-	camel_folder_freeze(folder);
+	camel_folder_freeze (folder);
 	for (i=0;i<uids->len;i++)
 		camel_folder_set_message_flags (
 			folder, uids->pdata[i],
 			CAMEL_MESSAGE_SEEN, CAMEL_MESSAGE_SEEN);
-	camel_folder_thaw(folder);
+	camel_folder_thaw (folder);
 	camel_folder_free_uids (folder, uids);
 }
 
 static gboolean
 mar_all_sub_folders (CamelStore *store,
                      CamelFolderInfo *fi,
+                     GCancellable *cancellable,
                      GError **error)
 {
 	while (fi) {
 		CamelFolder *folder;
 
 		if (fi->child) {
-			if (!mar_all_sub_folders (store, fi->child, error))
+			if (!mar_all_sub_folders (
+				store, fi->child, cancellable, error))
 				return FALSE;
 		}
 
-		folder = camel_store_get_folder (
-			store, fi->full_name, 0, error);
+		folder = camel_store_get_folder_sync (
+			store, fi->full_name, 0, cancellable, error);
 		if (folder == NULL)
 			return FALSE;
 
@@ -389,10 +391,11 @@ mar_got_folder (gchar *folder_uri,
 	full_name = camel_folder_get_full_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
 
-	folder_info = camel_store_get_folder_info (
+	/* FIXME Not passing a GCancellable or GError here. */
+	folder_info = camel_store_get_folder_info_sync (
 		parent_store, full_name,
 		CAMEL_STORE_FOLDER_INFO_RECURSIVE |
-		CAMEL_STORE_FOLDER_INFO_FAST, NULL);
+		CAMEL_STORE_FOLDER_INFO_FAST, NULL, NULL);
 
 	if (folder_info == NULL)
 		goto exit;
@@ -405,7 +408,8 @@ mar_got_folder (gchar *folder_uri,
 	if (response == MARK_ALL_READ_CURRENT_FOLDER)
 		mark_all_as_read (folder);
 	else if (response == MARK_ALL_READ_WITH_SUBFOLDERS)
-		mar_all_sub_folders (parent_store, folder_info, NULL);
+		/* FIXME Not passing a GCancellable or GError here. */
+		mar_all_sub_folders (parent_store, folder_info, NULL, NULL);
 
 exit:
 	camel_store_free_folder_info (parent_store, folder_info);
@@ -417,15 +421,19 @@ action_mail_mark_read_recursive_cb (GtkAction *action,
 {
 	EShellSidebar *shell_sidebar;
 	EMFolderTree *folder_tree;
+	EMailSession *session;
 	gchar *folder_uri;
 
 	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
 	g_object_get (shell_sidebar, "folder-tree", &folder_tree, NULL);
+
+	session = em_folder_tree_get_session (folder_tree);
+
 	folder_uri = em_folder_tree_get_selected_uri (folder_tree);
 	g_return_if_fail (folder_uri != NULL);
 
 	mail_get_folder (
-		folder_uri, 0, mar_got_folder,
+		session, folder_uri, 0, mar_got_folder,
 		NULL, mail_msg_unordered_push);
 
 	g_object_unref (folder_tree);
