@@ -20,6 +20,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
@@ -40,6 +44,10 @@
 #include "publish-format-fb.h"
 #include "publish-format-ical.h"
 
+#ifdef HAVE_LIBNOTIFY
+#include <libnotify/notify.h>
+#endif
+
 static GtkListStore *store = NULL;
 static GHashTable *uri_timeouts = NULL;
 static GSList *publish_uris = NULL;
@@ -56,6 +64,116 @@ GtkWidget   *publish_calendar_locations (EPlugin *epl, EConfigHookItemFactoryDat
 static void  update_timestamp (EPublishUri *uri);
 static void publish (EPublishUri *uri, gboolean can_report_success);
 
+static GtkStatusIcon *status_icon = NULL;
+static guint status_icon_timeout_id = 0;
+#ifdef HAVE_LIBNOTIFY
+static NotifyNotification *notify = NULL;
+
+static gboolean
+show_notify_cb (gpointer data)
+{
+	return notify && !notify_notification_show (notify, NULL);
+}
+#endif
+
+static gboolean
+remove_notification (gpointer data)
+{
+	if (status_icon_timeout_id)
+		g_source_remove (status_icon_timeout_id);
+	status_icon_timeout_id = 0;
+
+#ifdef HAVE_LIBNOTIFY
+	if (notify)
+		notify_notification_close (notify, NULL);
+	notify = NULL;
+#endif
+
+	gtk_status_icon_set_visible (status_icon, FALSE);
+	g_object_unref (status_icon);
+	status_icon = NULL;
+
+	return FALSE;
+}
+
+static void
+update_publish_notification (GtkMessageType msg_type, const gchar *msg_text)
+{
+	static GString *actual_msg = NULL;
+	#ifdef HAVE_LIBNOTIFY
+	static gboolean can_notify = TRUE;
+	#endif
+	gboolean new_icon = !status_icon;
+	const gchar *stock_name;
+
+	g_return_if_fail (msg_text != NULL);
+
+	if (new_icon) {
+		status_icon = gtk_status_icon_new ();
+		if (actual_msg) {
+			g_string_free (actual_msg, TRUE);
+			actual_msg = NULL;
+		}
+	} else if (status_icon_timeout_id) {
+		g_source_remove (status_icon_timeout_id);
+	}
+
+	switch (msg_type) {
+	case GTK_MESSAGE_WARNING:
+		stock_name = GTK_STOCK_DIALOG_WARNING;
+		break;
+	case GTK_MESSAGE_ERROR:
+		stock_name = GTK_STOCK_DIALOG_ERROR;
+		break;
+	default:
+		stock_name = GTK_STOCK_DIALOG_INFO;
+		break;
+	}
+
+	if (!actual_msg) {
+		actual_msg = g_string_new (msg_text);
+	} else {
+		g_string_append (actual_msg, "\n");
+		g_string_append (actual_msg, msg_text);
+	}
+
+	gtk_status_icon_set_from_stock (status_icon, stock_name);
+	gtk_status_icon_set_tooltip_text (status_icon, actual_msg->str);
+
+#ifdef HAVE_LIBNOTIFY
+	if (can_notify) {
+		if (notify) {
+			notify_notification_update (notify, _("Calendar Publishing"), actual_msg->str, stock_name);
+		} else {
+			if (!notify_init ("evolution-publish-calendar")) {
+				can_notify = FALSE;
+				return;
+			}
+
+#ifdef HAVE_LIBNOTIFY_07
+			notify  = notify_notification_new (_("Calendar Publishing"), actual_msg->str, stock_name);
+#else
+			notify  = notify_notification_new (_("Calendar Publishing"), actual_msg->str, stock_name, NULL);
+			notify_notification_attach_to_status_icon (notify, status_icon);
+#endif /* HAVE_LIBNOTIFY_07 */
+			notify_notification_set_urgency (notify, NOTIFY_URGENCY_NORMAL);
+			notify_notification_set_timeout (notify, NOTIFY_EXPIRES_DEFAULT);
+			g_timeout_add (500, show_notify_cb, NULL);
+
+			g_signal_connect (notify, "closed", G_CALLBACK (remove_notification), NULL);
+		}
+	}
+#endif
+
+	status_icon_timeout_id = g_timeout_add_seconds (15, remove_notification, NULL);
+
+	if (new_icon) {
+		g_signal_connect (
+			status_icon, "activate",
+			G_CALLBACK (remove_notification), NULL);
+	}
+}
+
 static void
 publish_no_succ_info (EPublishUri *uri)
 {
@@ -159,7 +277,6 @@ mount_ready_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
 	g_file_mount_enclosing_volume_finish (G_FILE (source_object), res, &error);
 
 	if (error) {
-
 		error_queue_add (g_strdup_printf (_("Mount of %s failed:"), ms->uri->location), error);
 
 		if (ms)
@@ -477,11 +594,10 @@ url_list_changed (PublishUIData *ui)
 static void
 update_url_enable_button (EPublishUri *url, GtkWidget *url_enable)
 {
-	g_return_if_fail (url != NULL);
 	g_return_if_fail (url_enable != NULL);
 	g_return_if_fail (GTK_IS_BUTTON (url_enable));
 
-	gtk_button_set_label (GTK_BUTTON (url_enable), url->enabled ? _("_Disable") : _("E_nable"));
+	gtk_button_set_label (GTK_BUTTON (url_enable), url && url->enabled ? _("_Disable") : _("E_nable"));
 }
 
 static void
@@ -489,7 +605,6 @@ url_list_enable_toggled (GtkCellRendererToggle *renderer,
                          const gchar            *path_string,
 			 PublishUIData         *ui)
 {
-	GtkTreeSelection *selection;
 	EPublishUri *url = NULL;
 	GtkTreeModel *model;
 	GtkTreePath *path;
@@ -497,7 +612,6 @@ url_list_enable_toggled (GtkCellRendererToggle *renderer,
 
 	path = gtk_tree_path_new_from_string (path_string);
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ui->treeview));
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (ui->treeview));
 
 	if (gtk_tree_model_get_iter (model, &iter, path)) {
 		gtk_tree_model_get (model, &iter, URL_LIST_URL_COLUMN, &url, -1);
@@ -526,13 +640,13 @@ selection_changed (GtkTreeSelection *selection, PublishUIData *ui)
 		gtk_widget_set_sensitive (ui->url_edit, TRUE);
 		gtk_widget_set_sensitive (ui->url_remove, TRUE);
 		gtk_widget_set_sensitive (ui->url_enable, TRUE);
-
-		update_url_enable_button (url, ui->url_enable);
 	} else {
 		gtk_widget_set_sensitive (ui->url_edit, FALSE);
 		gtk_widget_set_sensitive (ui->url_remove, FALSE);
 		gtk_widget_set_sensitive (ui->url_enable, FALSE);
 	}
+
+	update_url_enable_button (url, ui->url_enable);
 }
 
 static void
@@ -646,6 +760,8 @@ url_remove_clicked (GtkButton *button, PublishUIData *ui)
 			gtk_widget_set_sensitive (ui->url_edit, FALSE);
 			gtk_widget_set_sensitive (ui->url_remove, FALSE);
 			gtk_widget_set_sensitive (ui->url_enable, FALSE);
+
+			update_url_enable_button (NULL, ui->url_enable);
 		}
 
 		publish_uris = g_slist_remove (publish_uris, url);
@@ -698,7 +814,6 @@ publish_calendar_locations (EPlugin *epl, EConfigHookItemFactoryData *data)
 	PublishUIData *ui = g_new0 (PublishUIData, 1);
 	GSList *l;
 	GtkTreeIter iter;
-	GConfClient *client;
 
 	builder = gtk_builder_new ();
 	e_load_ui_builder_definition (builder, "publish-calendar.ui");
@@ -729,6 +844,7 @@ publish_calendar_locations (EPlugin *epl, EConfigHookItemFactoryData *data)
 	ui->url_edit = e_builder_get_widget (builder, "url edit");
 	ui->url_remove = e_builder_get_widget (builder, "url remove");
 	ui->url_enable = e_builder_get_widget (builder, "url enable");
+	update_url_enable_button (NULL, ui->url_enable);
 	g_signal_connect (G_OBJECT (ui->url_add), "clicked", G_CALLBACK (url_add_clicked), ui);
 	g_signal_connect (G_OBJECT (ui->url_edit), "clicked", G_CALLBACK (url_edit_clicked), ui);
 	g_signal_connect (G_OBJECT (ui->url_remove), "clicked", G_CALLBACK (url_remove_clicked), ui);
@@ -740,7 +856,6 @@ publish_calendar_locations (EPlugin *epl, EConfigHookItemFactoryData *data)
 	gtk_button_set_image (GTK_BUTTON (ui->url_enable), gtk_image_new_from_stock (GTK_STOCK_APPLY, GTK_ICON_SIZE_BUTTON));
 	gtk_button_set_use_underline (GTK_BUTTON (ui->url_enable), TRUE);
 
-	client = gconf_client_get_default ();
 	l = publish_uris;
 	while (l) {
 		EPublishUri *url = (EPublishUri *) l->data;
@@ -898,9 +1013,7 @@ error_queue_show_idle (gpointer user_data)
 	g_static_mutex_unlock (&error_queue_lock);
 
 	if (info) {
-		e_notice (NULL,
-			  has_error && has_info ? GTK_MESSAGE_WARNING : has_error ? GTK_MESSAGE_ERROR : GTK_MESSAGE_INFO,
-			  "%s", info->str, NULL);
+		update_publish_notification (has_error && has_info ? GTK_MESSAGE_WARNING : has_error ? GTK_MESSAGE_ERROR : GTK_MESSAGE_INFO, info->str);
 
 		g_string_free (info, TRUE);
 	}
@@ -935,8 +1048,12 @@ action_calendar_publish_cb (GtkAction *action,
 	GError *error = NULL;
 
 	thread = g_thread_create ((GThreadFunc) publish_urls, NULL, FALSE, &error);
-	if (!thread)
+	if (!thread) {
+		/* To Translators: This is shown to a user when creation of a new thread,
+		   where the publishing should be done, fails. Basically, this shouldn't
+		   ever happen, and if so, then something is really wrong. */
 		error_queue_add (g_strdup (_("Could not create publish thread.")), error);
+	}
 }
 
 static GtkActionEntry entries[] = {
