@@ -19,18 +19,27 @@
  *
  */
 
+/**
+ * SECTION: e-shell-searchbar
+ * @short_description: quick search interface
+ * @include: shell/e-shell-searchbar.h
+ **/
+
 #include "e-shell-searchbar.h"
 
 #include <config.h>
 #include <glib/gi18n-lib.h>
 
 #include "e-util/e-util.h"
-#include "e-util/e-binding.h"
+#include "e-util/e-extensible.h"
 #include "widgets/misc/e-action-combo-box.h"
 #include "widgets/misc/e-hinted-entry.h"
 
 #include "e-shell-window-actions.h"
 
+/* backward-compatibility cruft */
+#include "e-util/gtk-compat.h"
+
 #define E_SHELL_SEARCHBAR_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), E_TYPE_SHELL_SEARCHBAR, EShellSearchbarPrivate))
@@ -60,8 +69,9 @@ struct _EShellSearchbarPrivate {
 	/* State Key File */
 	gchar *state_group;
 
+	guint express_mode   : 1;
 	guint filter_visible : 1;
-	guint label_visible  : 1;
+	guint labels_visible : 1;
 	guint search_visible : 1;
 	guint scope_visible  : 1;
 	guint state_dirty    : 1;
@@ -69,9 +79,10 @@ struct _EShellSearchbarPrivate {
 
 enum {
 	PROP_0,
+	PROP_EXPRESS_MODE,
 	PROP_FILTER_COMBO_BOX,
 	PROP_FILTER_VISIBLE,
-	PROP_LABEL_VISIBLE,
+	PROP_LABELS_VISIBLE,
 	PROP_SEARCH_HINT,
 	PROP_SEARCH_OPTION,
 	PROP_SEARCH_TEXT,
@@ -82,7 +93,136 @@ enum {
 	PROP_STATE_GROUP
 };
 
-static gpointer parent_class;
+G_DEFINE_TYPE_WITH_CODE (
+	EShellSearchbar,
+	e_shell_searchbar,
+	GTK_TYPE_BOX,
+	G_IMPLEMENT_INTERFACE (
+		E_TYPE_EXTENSIBLE, NULL))
+
+static void
+shell_searchbar_save_search_filter (EShellSearchbar *searchbar)
+{
+	EShellView *shell_view;
+	EActionComboBox *action_combo_box;
+	GtkRadioAction *radio_action;
+	GKeyFile *key_file;
+	const gchar *action_name;
+	const gchar *state_group;
+	const gchar *key;
+
+	shell_view = e_shell_searchbar_get_shell_view (searchbar);
+	state_group = e_shell_searchbar_get_state_group (searchbar);
+	g_return_if_fail (state_group != NULL);
+
+	key = STATE_KEY_SEARCH_FILTER;
+	key_file = e_shell_view_get_state_key_file (shell_view);
+
+	action_combo_box = e_shell_searchbar_get_filter_combo_box (searchbar);
+	radio_action = e_action_combo_box_get_action (action_combo_box);
+
+	if (radio_action != NULL)
+		radio_action = e_radio_action_get_current_action (radio_action);
+
+	if (radio_action != NULL) {
+		action_name = gtk_action_get_name (GTK_ACTION (radio_action));
+		g_key_file_set_string (key_file, state_group, key, action_name);
+	} else
+		g_key_file_remove_key (key_file, state_group, key, NULL);
+
+	e_shell_view_set_state_dirty (shell_view);
+}
+
+static void
+shell_searchbar_save_search_option (EShellSearchbar *searchbar)
+{
+	EShellView *shell_view;
+	GtkRadioAction *radio_action;
+	GKeyFile *key_file;
+	const gchar *action_name;
+	const gchar *state_group;
+	const gchar *key;
+
+	shell_view = e_shell_searchbar_get_shell_view (searchbar);
+	state_group = e_shell_searchbar_get_state_group (searchbar);
+	g_return_if_fail (state_group != NULL);
+
+	key = STATE_KEY_SEARCH_OPTION;
+	key_file = e_shell_view_get_state_key_file (shell_view);
+
+	radio_action = e_shell_searchbar_get_search_option (searchbar);
+
+	if (radio_action != NULL)
+		radio_action = e_radio_action_get_current_action (radio_action);
+
+	if (radio_action != NULL) {
+		action_name = gtk_action_get_name (GTK_ACTION (radio_action));
+		g_key_file_set_string (key_file, state_group, key, action_name);
+	} else
+		g_key_file_remove_key (key_file, state_group, key, NULL);
+
+	e_shell_view_set_state_dirty (shell_view);
+}
+
+static void
+shell_searchbar_save_search_text (EShellSearchbar *searchbar)
+{
+	EShellView *shell_view;
+	GKeyFile *key_file;
+	const gchar *search_text;
+	const gchar *state_group;
+	const gchar *key;
+
+	shell_view = e_shell_searchbar_get_shell_view (searchbar);
+	state_group = e_shell_searchbar_get_state_group (searchbar);
+	g_return_if_fail (state_group != NULL);
+
+	key = STATE_KEY_SEARCH_TEXT;
+	key_file = e_shell_view_get_state_key_file (shell_view);
+
+	search_text = e_shell_searchbar_get_search_text (searchbar);
+
+	if (search_text != NULL && *search_text != '\0')
+		g_key_file_set_string (key_file, state_group, key, search_text);
+	else
+		g_key_file_remove_key (key_file, state_group, key, NULL);
+
+	e_shell_view_set_state_dirty (shell_view);
+}
+
+static void
+shell_searchbar_save_search_scope (EShellSearchbar *searchbar)
+{
+	EShellView *shell_view;
+	EActionComboBox *action_combo_box;
+	GtkRadioAction *radio_action;
+	GKeyFile *key_file;
+	const gchar *action_name;
+	const gchar *state_group;
+	const gchar *key;
+
+	shell_view = e_shell_searchbar_get_shell_view (searchbar);
+
+	/* Search scope is hard-coded to the default state group. */
+	state_group = STATE_GROUP_DEFAULT;
+
+	key = STATE_KEY_SEARCH_SCOPE;
+	key_file = e_shell_view_get_state_key_file (shell_view);
+
+	action_combo_box = e_shell_searchbar_get_scope_combo_box (searchbar);
+	radio_action = e_action_combo_box_get_action (action_combo_box);
+
+	if (radio_action != NULL)
+		radio_action = e_radio_action_get_current_action (radio_action);
+
+	if (radio_action != NULL) {
+		action_name = gtk_action_get_name (GTK_ACTION (radio_action));
+		g_key_file_set_string (key_file, state_group, key, action_name);
+	} else
+		g_key_file_remove_key (key_file, state_group, key, NULL);
+
+	e_shell_view_set_state_dirty (shell_view);
+}
 
 static void
 shell_searchbar_update_search_widgets (EShellSearchbar *searchbar)
@@ -165,7 +305,7 @@ static void
 shell_searchbar_execute_search_cb (EShellView *shell_view,
                                    EShellSearchbar *searchbar)
 {
-	GtkWidget *widget;
+	EShellContent *shell_content;
 
 	shell_searchbar_update_search_widgets (searchbar);
 
@@ -177,9 +317,10 @@ shell_searchbar_execute_search_cb (EShellView *shell_view,
 	/* Direct the focus away from the search entry, so that a
 	 * focus-in event is required before the text can be changed.
 	 * This will reset the entry to the appropriate visual state. */
-	widget = searchbar->priv->search_entry;
-	if (gtk_widget_is_focus (widget))
-		gtk_widget_child_focus (widget, GTK_DIR_TAB_FORWARD);
+	if (gtk_widget_is_focus (searchbar->priv->search_entry)) {
+		shell_content = e_shell_view_get_shell_content (shell_view);
+		e_shell_content_focus_search_results (shell_content);
+	}
 }
 
 static void
@@ -277,7 +418,7 @@ shell_searchbar_entry_key_press_cb (EShellSearchbar *searchbar,
 	if ((key_event->state & mask) != GDK_MOD1_MASK)
 		return FALSE;
 
-	if (key_event->keyval != GDK_Down)
+	if (key_event->keyval != GDK_KEY_Down)
 		return FALSE;
 
 	shell_view = e_shell_searchbar_get_shell_view (searchbar);
@@ -312,6 +453,11 @@ shell_searchbar_option_changed_cb (GtkRadioAction *action,
 		e_shell_searchbar_set_search_text (searchbar, search_text);
 		if (search_text != NULL && *search_text != '\0')
 			e_shell_view_execute_search (shell_view);
+		else {
+			shell_searchbar_save_search_option (searchbar);
+			gtk_widget_grab_focus (searchbar->priv->search_entry);
+		}
+
 	} else if (search_text != NULL)
 		e_shell_searchbar_set_search_text (searchbar, NULL);
 }
@@ -336,14 +482,20 @@ shell_searchbar_set_property (GObject *object,
                               GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_EXPRESS_MODE:
+			e_shell_searchbar_set_express_mode (
+				E_SHELL_SEARCHBAR (object),
+				g_value_get_boolean (value));
+			return;
+
 		case PROP_FILTER_VISIBLE:
 			e_shell_searchbar_set_filter_visible (
 				E_SHELL_SEARCHBAR (object),
 				g_value_get_boolean (value));
 			return;
 
-		case PROP_LABEL_VISIBLE:
-			e_shell_searchbar_set_label_visible (
+		case PROP_LABELS_VISIBLE:
+			e_shell_searchbar_set_labels_visible (
 				E_SHELL_SEARCHBAR (object),
 				g_value_get_boolean (value));
 			return;
@@ -401,15 +553,21 @@ shell_searchbar_get_property (GObject *object,
                               GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_EXPRESS_MODE:
+			g_value_set_boolean (
+				value, e_shell_searchbar_get_express_mode (
+				E_SHELL_SEARCHBAR (object)));
+			return;
+
 		case PROP_FILTER_COMBO_BOX:
 			g_value_set_object (
 				value, e_shell_searchbar_get_filter_combo_box (
 				E_SHELL_SEARCHBAR (object)));
 			return;
 
-		case PROP_LABEL_VISIBLE:
+		case PROP_LABELS_VISIBLE:
 			g_value_set_boolean (
-				value, e_shell_searchbar_get_label_visible (
+				value, e_shell_searchbar_get_labels_visible (
 				E_SHELL_SEARCHBAR (object)));
 			return;
 
@@ -492,8 +650,13 @@ shell_searchbar_dispose (GObject *object)
 		priv->search_option = NULL;
 	}
 
+	if (priv->state_group) {
+		g_free (priv->state_group);
+		priv->state_group = NULL;
+	}
+
 	/* Chain up to parent's dispose() method. */
-	G_OBJECT_CLASS (parent_class)->dispose (object);
+	G_OBJECT_CLASS (e_shell_searchbar_parent_class)->dispose (object);
 }
 
 static void
@@ -529,45 +692,58 @@ shell_searchbar_constructed (GObject *object)
 		widget, "changed",
 		G_CALLBACK (e_shell_searchbar_set_state_dirty), searchbar);
 
-	g_signal_connect_swapped (
+	/* Use G_CONNECT_AFTER here so the EActionComboBox has a
+	 * chance to update its radio actions before we go sifting
+	 * through the radio group for the current action. */
+	g_signal_connect_data (
 		widget, "changed",
-		G_CALLBACK (e_shell_view_execute_search), shell_view);
+		G_CALLBACK (e_shell_view_execute_search),
+		shell_view, (GClosureNotify) NULL,
+		G_CONNECT_AFTER | G_CONNECT_SWAPPED);
 
 	widget = searchbar->priv->search_entry;
 
 	action = E_SHELL_WINDOW_ACTION_SEARCH_CLEAR (shell_window);
 
-	e_binding_new (
+	g_object_bind_property (
 		action, "sensitive",
-		widget, "secondary-icon-sensitive");
-	e_binding_new (
+		widget, "secondary-icon-sensitive",
+		G_BINDING_SYNC_CREATE);
+	g_object_bind_property (
 		action, "stock-id",
-		widget, "secondary-icon-stock");
-	e_binding_new (
+		widget, "secondary-icon-stock",
+		G_BINDING_SYNC_CREATE);
+	g_object_bind_property (
 		action, "tooltip",
-		widget, "secondary-icon-tooltip-text");
+		widget, "secondary-icon-tooltip-text",
+		G_BINDING_SYNC_CREATE);
 
 	action = E_SHELL_WINDOW_ACTION_SEARCH_OPTIONS (shell_window);
 
-	e_binding_new (
+	g_object_bind_property (
 		action, "sensitive",
-		widget, "primary-icon-sensitive");
-	e_binding_new (
+		widget, "primary-icon-sensitive",
+		G_BINDING_SYNC_CREATE);
+	g_object_bind_property (
 		action, "stock-id",
-		widget, "primary-icon-stock");
-	e_binding_new (
+		widget, "primary-icon-stock",
+		G_BINDING_SYNC_CREATE);
+	g_object_bind_property (
 		action, "tooltip",
-		widget, "primary-icon-tooltip-text");
+		widget, "primary-icon-tooltip-text",
+		G_BINDING_SYNC_CREATE);
 
 	widget = GTK_WIDGET (searchbar);
 	gtk_size_group_add_widget (size_group, widget);
+
+	e_extensible_load_extensions (E_EXTENSIBLE (object));
 }
 
 static void
 shell_searchbar_map (GtkWidget *widget)
 {
 	/* Chain up to parent's map() method. */
-	GTK_WIDGET_CLASS (parent_class)->map (widget);
+	GTK_WIDGET_CLASS (e_shell_searchbar_parent_class)->map (widget);
 
 	/* Load state after constructed() so we don't derail
 	 * subclass initialization.  We wait until map() so we
@@ -576,12 +752,11 @@ shell_searchbar_map (GtkWidget *widget)
 }
 
 static void
-shell_searchbar_class_init (EShellSearchbarClass *class)
+e_shell_searchbar_class_init (EShellSearchbarClass *class)
 {
 	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (EShellSearchbarPrivate));
 
 	object_class = G_OBJECT_CLASS (class);
@@ -593,6 +768,17 @@ shell_searchbar_class_init (EShellSearchbarClass *class)
 	widget_class = GTK_WIDGET_CLASS (class);
 	widget_class->map = shell_searchbar_map;
 
+	g_object_class_install_property (
+		object_class,
+		PROP_EXPRESS_MODE,
+		g_param_spec_boolean (
+			"express-mode",
+			NULL,
+			NULL,
+			FALSE,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT));
+
 	g_object_class_install_property (
 		object_class,
 		PROP_FILTER_COMBO_BOX,
@@ -605,9 +791,9 @@ shell_searchbar_class_init (EShellSearchbarClass *class)
 
 	g_object_class_install_property (
 		object_class,
-		PROP_LABEL_VISIBLE,
+		PROP_LABELS_VISIBLE,
 		g_param_spec_boolean (
-			"label-visible",
+			"labels-visible",
 			NULL,
 			NULL,
 			TRUE,
@@ -688,7 +874,7 @@ shell_searchbar_class_init (EShellSearchbarClass *class)
 			G_PARAM_CONSTRUCT));
 
 	/**
-	 * EShellContent:shell-view
+	 * EShellSearchbar:shell-view
 	 *
 	 * The #EShellView to which the searchbar widget belongs.
 	 **/
@@ -704,7 +890,7 @@ shell_searchbar_class_init (EShellSearchbarClass *class)
 			G_PARAM_CONSTRUCT_ONLY));
 
 	/**
-	 * EShellContent:state-group
+	 * EShellSearchbar:state-group
 	 *
 	 * Key file group name to read and write search bar state.
 	 **/
@@ -721,7 +907,7 @@ shell_searchbar_class_init (EShellSearchbarClass *class)
 }
 
 static void
-shell_searchbar_init (EShellSearchbar *searchbar)
+e_shell_searchbar_init (EShellSearchbar *searchbar)
 {
 	GtkBox *box;
 	GtkLabel *label;
@@ -738,9 +924,10 @@ shell_searchbar_init (EShellSearchbar *searchbar)
 	widget = gtk_hbox_new (FALSE, 3);
 	gtk_box_pack_start (box, widget, FALSE, FALSE, 0);
 
-	e_binding_new (
+	g_object_bind_property (
 		searchbar, "filter-visible",
-		widget, "visible");
+		widget, "visible",
+		G_BINDING_SYNC_CREATE);
 
 	box = GTK_BOX (widget);
 
@@ -752,6 +939,11 @@ shell_searchbar_init (EShellSearchbar *searchbar)
 	gtk_box_pack_start (box, widget, FALSE, FALSE, 0);
 	gtk_widget_show (widget);
 
+	g_object_bind_property (
+		searchbar, "labels-visible",
+		widget, "visible",
+		G_BINDING_SYNC_CREATE);
+
 	label = GTK_LABEL (widget);
 
 	widget = e_action_combo_box_new ();
@@ -767,9 +959,10 @@ shell_searchbar_init (EShellSearchbar *searchbar)
 	widget = gtk_hbox_new (FALSE, 3);
 	gtk_box_pack_start (box, widget, TRUE, TRUE, 0);
 
-	e_binding_new (
+	g_object_bind_property (
 		searchbar, "search-visible",
-		widget, "visible");
+		widget, "visible",
+		G_BINDING_SYNC_CREATE);
 
 	box = GTK_BOX (widget);
 
@@ -779,10 +972,12 @@ shell_searchbar_init (EShellSearchbar *searchbar)
 	gtk_box_pack_start (box, widget, FALSE, FALSE, 0);
 	gtk_widget_show (widget);
 
+	g_object_bind_property (
+		searchbar, "labels-visible",
+		widget, "visible",
+		G_BINDING_SYNC_CREATE);
+
 	label = GTK_LABEL (widget);
-	e_binding_new (
-		searchbar, "label-visible",
-		widget, "visible");
 
 	widget = e_hinted_entry_new ();
 	gtk_label_set_mnemonic_widget (label, widget);
@@ -827,9 +1022,10 @@ shell_searchbar_init (EShellSearchbar *searchbar)
 	widget = gtk_hbox_new (FALSE, 3);
 	gtk_box_pack_start (box, widget, FALSE, FALSE, 0);
 
-	e_binding_new (
+	g_object_bind_property (
 		searchbar, "scope-visible",
-		widget, "visible");
+		widget, "visible",
+		G_BINDING_SYNC_CREATE);
 
 	box = GTK_BOX (widget);
 
@@ -847,36 +1043,14 @@ shell_searchbar_init (EShellSearchbar *searchbar)
 	searchbar->priv->scope_combo_box = widget;
 	gtk_widget_show (widget);
 
-	g_signal_connect_swapped (
+	/* Use G_CONNECT_AFTER here so the EActionComboBox has a
+	 * chance to update its radio actions before we go sifting
+	 * through the radio group for the current action. */
+	g_signal_connect_data (
 		widget, "changed",
-		G_CALLBACK (e_shell_searchbar_set_state_dirty),
-		searchbar);
-}
-
-GType
-e_shell_searchbar_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0)) {
-		static const GTypeInfo type_info = {
-			sizeof (EShellSearchbarClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) shell_searchbar_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,  /* class_data */
-			sizeof (EShellSearchbar),
-			0,     /* n_preallocs */
-			(GInstanceInitFunc) shell_searchbar_init,
-			NULL   /* value_table */
-		};
-
-		type = g_type_register_static (
-			GTK_TYPE_BOX, "EShellSearchbar", &type_info, 0);
-	}
-
-	return type;
+		G_CALLBACK (shell_searchbar_save_search_scope),
+		searchbar, (GClosureNotify) NULL,
+		G_CONNECT_AFTER | G_CONNECT_SWAPPED);
 }
 
 /**
@@ -912,6 +1086,31 @@ e_shell_searchbar_get_shell_view (EShellSearchbar *searchbar)
 	return E_SHELL_VIEW (searchbar->priv->shell_view);
 }
 
+gboolean
+e_shell_searchbar_get_express_mode (EShellSearchbar *searchbar)
+{
+	g_return_val_if_fail (E_IS_SHELL_SEARCHBAR (searchbar), FALSE);
+
+	return searchbar->priv->express_mode;
+}
+
+void
+e_shell_searchbar_set_express_mode (EShellSearchbar *searchbar,
+                                    gboolean express_mode)
+{
+	g_return_if_fail (E_IS_SHELL_SEARCHBAR (searchbar));
+
+	searchbar->priv->express_mode = express_mode;
+
+	/* Emit "notify" on all the properties we override. */
+	g_object_freeze_notify (G_OBJECT (searchbar));
+	g_object_notify (G_OBJECT (searchbar), "express-mode");
+	g_object_notify (G_OBJECT (searchbar), "labels-visible");
+	g_object_notify (G_OBJECT (searchbar), "filter-visible");
+	g_object_notify (G_OBJECT (searchbar), "scope-visible");
+	g_object_thaw_notify (G_OBJECT (searchbar));
+}
+
 EActionComboBox *
 e_shell_searchbar_get_filter_combo_box (EShellSearchbar *searchbar)
 {
@@ -921,22 +1120,26 @@ e_shell_searchbar_get_filter_combo_box (EShellSearchbar *searchbar)
 }
 
 gboolean
-e_shell_searchbar_get_label_visible (EShellSearchbar *searchbar)
+e_shell_searchbar_get_labels_visible (EShellSearchbar *searchbar)
 {
 	g_return_val_if_fail (E_IS_SHELL_SEARCHBAR (searchbar), FALSE);
 
-	return searchbar->priv->label_visible;
+	/* Express mode overrides this. */
+	if (e_shell_searchbar_get_express_mode (searchbar))
+		return FALSE;
+
+	return searchbar->priv->labels_visible;
 }
 
 void
-e_shell_searchbar_set_label_visible (EShellSearchbar *searchbar,
-                                     gboolean label_visible)
+e_shell_searchbar_set_labels_visible (EShellSearchbar *searchbar,
+                                      gboolean labels_visible)
 {
 	g_return_if_fail (E_IS_SHELL_SEARCHBAR (searchbar));
 
-	searchbar->priv->label_visible = label_visible;
+	searchbar->priv->labels_visible = labels_visible;
 
-	g_object_notify (G_OBJECT (searchbar), "label-visible");
+	g_object_notify (G_OBJECT (searchbar), "labels-visible");
 }
 
 gboolean
@@ -944,6 +1147,10 @@ e_shell_searchbar_get_filter_visible (EShellSearchbar *searchbar)
 {
 	g_return_val_if_fail (E_IS_SHELL_SEARCHBAR (searchbar), FALSE);
 
+	/* Express mode overrides this. */
+	if (e_shell_searchbar_get_express_mode (searchbar))
+		return FALSE;
+
 	return searchbar->priv->filter_visible;
 }
 
@@ -1084,6 +1291,10 @@ e_shell_searchbar_get_scope_visible (EShellSearchbar *searchbar)
 {
 	g_return_val_if_fail (E_IS_SHELL_SEARCHBAR (searchbar), FALSE);
 
+	/* Express mode overrides this. */
+	if (e_shell_searchbar_get_express_mode (searchbar))
+		return FALSE;
+
 	return searchbar->priv->scope_visible;
 }
 
@@ -1129,6 +1340,14 @@ e_shell_searchbar_set_state_group (EShellSearchbar *searchbar,
 	g_object_notify (G_OBJECT (searchbar), "state-group");
 }
 
+static gboolean
+idle_execute_search (gpointer shell_view)
+{
+	e_shell_view_execute_search (shell_view);
+	g_object_unref (shell_view);
+	return FALSE;
+}
+
 void
 e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 {
@@ -1137,6 +1356,7 @@ e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 	GKeyFile *key_file;
 	GtkAction *action;
 	GtkWidget *widget;
+	gboolean express_mode;
 	const gchar *search_text;
 	const gchar *state_group;
 	const gchar *key;
@@ -1152,6 +1372,8 @@ e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 	key_file = e_shell_view_get_state_key_file (shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
+	express_mode = e_shell_searchbar_get_express_mode (searchbar);
+
 	/* Changing the combo boxes triggers searches, so block
 	 * the search action until the state is fully restored. */
 	action = E_SHELL_WINDOW_ACTION_SEARCH_QUICK (shell_window);
@@ -1163,7 +1385,7 @@ e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 
 	key = STATE_KEY_SEARCH_FILTER;
 	string = g_key_file_get_string (key_file, state_group, key, NULL);
-	if (string != NULL && *string != '\0')
+	if (string != NULL && *string != '\0' && !express_mode)
 		action = e_shell_window_get_action (shell_window, string);
 	else
 		action = NULL;
@@ -1193,6 +1415,7 @@ e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 	else if (searchbar->priv->search_option != NULL)
 		gtk_radio_action_set_current_value (
 			searchbar->priv->search_option, 0);
+	g_free (string);
 
 	key = STATE_KEY_SEARCH_TEXT;
 	string = g_key_file_get_string (key_file, state_group, key, NULL);
@@ -1208,7 +1431,7 @@ e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 
 	key = STATE_KEY_SEARCH_SCOPE;
 	string = g_key_file_get_string (key_file, state_group, key, NULL);
-	if (string != NULL && *string != '\0')
+	if (string != NULL && *string != '\0' && !express_mode)
 		action = e_shell_window_get_action (shell_window, string);
 	else
 		action = NULL;
@@ -1226,79 +1449,28 @@ e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 	action = E_SHELL_WINDOW_ACTION_SEARCH_QUICK (shell_window);
 	gtk_action_unblock_activate (action);
 
-	/* Now execute the search. */
+	/* Execute the search when we have time. */
+	g_object_ref (shell_view);
 	searchbar->priv->state_dirty = FALSE;
-	e_shell_view_execute_search (shell_view);
+	g_idle_add (idle_execute_search, shell_view);
 }
 
 void
 e_shell_searchbar_save_state (EShellSearchbar *searchbar)
 {
-	EShellView *shell_view;
-	GKeyFile *key_file;
-	GtkRadioAction *radio_action;
-	EActionComboBox *action_combo_box;
-	const gchar *action_name;
-	const gchar *search_text;
-	const gchar *state_group;
-	const gchar *key;
-
 	g_return_if_fail (E_IS_SHELL_SEARCHBAR (searchbar));
 
 	/* Skip saving state if it hasn't changed since it was loaded. */
 	if (!searchbar->priv->state_dirty)
 		return;
 
-	shell_view = e_shell_searchbar_get_shell_view (searchbar);
-	state_group = e_shell_searchbar_get_state_group (searchbar);
-	g_return_if_fail (state_group != NULL);
+	shell_searchbar_save_search_filter (searchbar);
 
-	key_file = e_shell_view_get_state_key_file (shell_view);
+	shell_searchbar_save_search_option (searchbar);
 
-	key = STATE_KEY_SEARCH_FILTER;
-	action_combo_box = e_shell_searchbar_get_filter_combo_box (searchbar);
-	radio_action = e_action_combo_box_get_action (action_combo_box);
-	if (radio_action != NULL)
-		radio_action = e_radio_action_get_current_action (radio_action);
-	if (radio_action != NULL) {
-		action_name = gtk_action_get_name (GTK_ACTION (radio_action));
-		g_key_file_set_string (key_file, state_group, key, action_name);
-	} else
-		g_key_file_remove_key (key_file, state_group, key, NULL);
+	shell_searchbar_save_search_text (searchbar);
 
-	key = STATE_KEY_SEARCH_OPTION;
-	radio_action = e_shell_searchbar_get_search_option (searchbar);
-	if (radio_action != NULL)
-		radio_action = e_radio_action_get_current_action (radio_action);
-	if (radio_action != NULL) {
-		action_name = gtk_action_get_name (GTK_ACTION (radio_action));
-		g_key_file_set_string (key_file, state_group, key, action_name);
-	} else
-		g_key_file_remove_key (key_file, state_group, key, NULL);
-
-	key = STATE_KEY_SEARCH_TEXT;
-	search_text = e_shell_searchbar_get_search_text (searchbar);
-	if (search_text != NULL && *search_text == '\0')
-		search_text = NULL;
-	if (search_text != NULL)
-		g_key_file_set_string (key_file, state_group, key, search_text);
-	else
-		g_key_file_remove_key (key_file, state_group, key, NULL);
-
-	/* Search scope is hard-coded to the default state group. */
-	state_group = STATE_GROUP_DEFAULT;
-
-	key = STATE_KEY_SEARCH_SCOPE;
-	action_combo_box = e_shell_searchbar_get_scope_combo_box (searchbar);
-	radio_action = e_action_combo_box_get_action (action_combo_box);
-	if (radio_action != NULL)
-		radio_action = e_radio_action_get_current_action (radio_action);
-	if (radio_action != NULL) {
-		action_name = gtk_action_get_name (GTK_ACTION (radio_action));
-		g_key_file_set_string (key_file, state_group, key, action_name);
-	} else
-		g_key_file_remove_key (key_file, state_group, key, NULL);
+	shell_searchbar_save_search_scope (searchbar);
 
 	searchbar->priv->state_dirty = FALSE;
-	e_shell_view_set_state_dirty (shell_view);
 }
