@@ -22,9 +22,7 @@
 #include "e-shell-window-private.h"
 #include "e-preferences-window.h"
 
-#include <e-util/e-util-private.h>
 #include <e-util/e-dialog-utils.h>
-#include <e-util/e-alert-dialog.h>
 #include <e-util/e-print.h>
 #include <gal-define-views-dialog.h>
 
