@@ -23,7 +23,6 @@
 
 #include <glib/gi18n.h>
 
-#include "e-util/e-binding.h"
 #include "e-util/gconf-bridge.h"
 
 #include "e-attachment-view.h"
@@ -31,6 +30,9 @@
 #include "e-attachment-icon-view.h"
 #include "e-attachment-tree-view.h"
 
+/* backward-compatibility cruft */
+#include "e-util/gtk-compat.h"
+
 #define E_ATTACHMENT_PANED_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), E_TYPE_ATTACHMENT_PANED, EAttachmentPanedPrivate))
@@ -292,41 +294,59 @@ attachment_paned_constructed (GObject *object)
 
 	/* Set up property-to-property bindings. */
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		object, "active-view",
-		priv->combo_box, "active");
+		priv->combo_box, "active",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		object, "active-view",
-		priv->notebook, "page");
+		priv->notebook, "page",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		object, "dragging",
-		priv->icon_view, "dragging");
+		priv->icon_view, "dragging",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		object, "dragging",
-		priv->tree_view, "dragging");
+		priv->tree_view, "dragging",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		object, "editable",
-		priv->icon_view, "editable");
+		priv->icon_view, "editable",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		object, "editable",
-		priv->tree_view, "editable");
+		priv->tree_view, "editable",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		object, "expanded",
-		priv->expander, "expanded");
+		priv->expander, "expanded",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		object, "expanded",
-		priv->combo_box, "sensitive");
+		priv->combo_box, "sensitive",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		object, "expanded",
-		priv->notebook, "visible");
+		priv->notebook, "visible",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
 	/* Set up property-to-GConf bindings. */
 
@@ -580,6 +600,7 @@ e_attachment_paned_init (EAttachmentPaned *paned)
 
 	widget = gtk_expander_new (NULL);
 	gtk_expander_set_spacing (GTK_EXPANDER (widget), 0);
+	gtk_expander_set_label_fill (GTK_EXPANDER (widget), TRUE);
 	gtk_box_pack_start (GTK_BOX (container), widget, TRUE, TRUE, 0);
 	paned->priv->expander = g_object_ref (widget);
 	gtk_widget_show (widget);
@@ -594,35 +615,20 @@ e_attachment_paned_init (EAttachmentPaned *paned)
 	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
 	gtk_widget_show (widget);
 
-	widget = gtk_combo_box_new_text ();
+	widget = gtk_combo_box_text_new ();
 	gtk_size_group_add_widget (size_group, widget);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Icon View"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("List View"));
+	gtk_combo_box_text_append_text (
+		GTK_COMBO_BOX_TEXT (widget), _("Icon View"));
+	gtk_combo_box_text_append_text (
+		GTK_COMBO_BOX_TEXT (widget), _("List View"));
 	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
 	paned->priv->combo_box = g_object_ref (widget);
 	gtk_widget_show (widget);
 
 	container = paned->priv->expander;
 
-	/* Request the width to be as large as possible, and let the
-	 * GtkExpander allocate what space there is.  This effectively
-	 * packs the widget to expand.
-	 *
-	 * XXX This hack causes nasty side-effects in RTL locales,
-	 *     so check the reading direction before applying it.
-	 *     See GNOME bug #614049 for details + screenshot.
-	 *
-	 * XXX It also trips a height-for-width assertion GTK+ 3.
-	 *     The same GNOME bug has a patch to add a "label-fill"
-	 *     boolean property to GtkExpander to allow me to do
-	 *     what I'm trying to do here properly.
-	 */
 	widget = gtk_hbox_new (FALSE, 6);
 	gtk_size_group_add_widget (size_group, widget);
-#if !GTK_CHECK_VERSION(2,90,0)
-	if (gtk_widget_get_direction (widget) != GTK_TEXT_DIR_RTL)
-		gtk_widget_set_size_request (widget, G_MAXINT, -1);
-#endif
 	gtk_expander_set_label_widget (GTK_EXPANDER (container), widget);
 	gtk_widget_show (widget);
 
