@@ -38,6 +38,9 @@
 #include <e-util/e-util.h>
 #include <e-util/e-extensible.h>
 
+/* backward-compatibility cruft */
+#include "e-util/gtk-compat.h"
+
 static const gint e_calendar_item_days_in_month[12] = {
 	31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
 };
@@ -47,11 +50,11 @@ static const gint e_calendar_item_days_in_month[12] = {
   && ((year) % 4 == 0 && ((year) % 100 != 0 || (year) % 400 == 0))) ? 1 : 0)
 
 static void e_calendar_item_dispose	(GObject	 *object);
-static void e_calendar_item_get_property(GObject	 *object,
+static void e_calendar_item_get_property (GObject	 *object,
 					 guint		  property_id,
 					 GValue		 *value,
 					 GParamSpec	 *pspec);
-static void e_calendar_item_set_property(GObject	 *object,
+static void e_calendar_item_set_property (GObject	 *object,
 					 guint		  property_id,
 					 const GValue	 *value,
 					 GParamSpec	 *pspec);
@@ -59,8 +62,7 @@ static void e_calendar_item_realize	(GnomeCanvasItem *item);
 static void e_calendar_item_unrealize	(GnomeCanvasItem *item);
 static void e_calendar_item_unmap	(GnomeCanvasItem *item);
 static void e_calendar_item_update	(GnomeCanvasItem *item,
-					 gdouble		 *affine,
-					 ArtSVP		 *clip_path,
+					 const cairo_matrix_t *i2c,
 					 gint		  flags);
 static void e_calendar_item_draw	(GnomeCanvasItem *item,
 					 GdkDrawable	 *drawable,
@@ -87,12 +89,11 @@ static void e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 					      gint		 start_weekday,
 					      gint		 cells_x,
 					      gint		 cells_y);
-static gdouble e_calendar_item_point	(GnomeCanvasItem *item,
+static GnomeCanvasItem *e_calendar_item_point	(GnomeCanvasItem *item,
 					 gdouble		  x,
 					 gdouble		  y,
 					 gint		  cx,
-					 gint		  cy,
-					 GnomeCanvasItem **actual_item);
+					 gint		  cy);
 static void e_calendar_item_stop_selecting (ECalendarItem *calitem,
 					    guint32 time);
 static void e_calendar_item_selection_add_days (ECalendarItem *calitem,
@@ -125,7 +126,7 @@ static void e_calendar_item_get_month_info	(ECalendarItem	*calitem,
 						 gint		*first_day_offset,
 						 gint		*days_in_month,
 						 gint		*days_in_prev_month);
-static void e_calendar_item_recalc_sizes(ECalendarItem *calitem);
+static void e_calendar_item_recalc_sizes (ECalendarItem *calitem);
 
 static void e_calendar_item_get_day_style	(ECalendarItem	*calitem,
 						 gint		 year,
@@ -147,12 +148,12 @@ static void e_calendar_item_check_selection_end	(ECalendarItem	*calitem,
 						 gint		 start_day,
 						 gint		*end_month,
 						 gint		*end_day);
-static void e_calendar_item_check_selection_start(ECalendarItem	*calitem,
+static void e_calendar_item_check_selection_start (ECalendarItem	*calitem,
 						  gint		*start_month,
 						  gint		*start_day,
 						  gint		 end_month,
 						  gint		 end_day);
-static void e_calendar_item_add_days_to_selection(ECalendarItem	*calitem,
+static void e_calendar_item_add_days_to_selection (ECalendarItem	*calitem,
 						  gint		 days);
 static void e_calendar_item_round_up_selection	(ECalendarItem	*calitem,
 						 gint		*month_offset,
@@ -179,7 +180,7 @@ static gboolean e_calendar_item_ensure_days_visible (ECalendarItem *calitem,
 static void e_calendar_item_show_popup_menu	(ECalendarItem	*calitem,
 						 GdkEventButton	*event,
 						 gint		 month_offset);
-static void e_calendar_item_on_menu_item_activate(GtkWidget	*menuitem,
+static void e_calendar_item_on_menu_item_activate (GtkWidget	*menuitem,
 						  ECalendarItem	*calitem);
 static void e_calendar_item_position_menu	(GtkMenu            *menu,
 						 gint               *x,
@@ -190,8 +191,8 @@ static void e_calendar_item_date_range_changed	(ECalendarItem	*calitem);
 static void e_calendar_item_queue_signal_emission	(ECalendarItem	*calitem);
 static gboolean e_calendar_item_signal_emission_idle_cb	(gpointer data);
 static void e_calendar_item_set_selection_if_emission (ECalendarItem	*calitem,
-						       GDate		*start_date,
-						       GDate		*end_date,
+						       const GDate	*start_date,
+						       const GDate	*end_date,
 						       gboolean emission);
 
 /* Our arguments. */
@@ -231,8 +232,11 @@ enum {
 static guint e_calendar_item_signals[LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE_WITH_CODE (
-	ECalendarItem, e_calendar_item, GNOME_TYPE_CANVAS_ITEM,
-	G_IMPLEMENT_INTERFACE (E_TYPE_EXTENSIBLE, NULL))
+	ECalendarItem,
+	e_calendar_item,
+	GNOME_TYPE_CANVAS_ITEM,
+	G_IMPLEMENT_INTERFACE (
+		E_TYPE_EXTENSIBLE, NULL))
 
 static void
 e_calendar_item_class_init (ECalendarItemClass *class)
@@ -847,7 +851,7 @@ e_calendar_item_realize		(GnomeCanvasItem *item)
 
 	calitem = E_CALENDAR_ITEM (item);
 
-	e_calendar_item_style_set (GTK_WIDGET(item->canvas), calitem);
+	e_calendar_item_style_set (GTK_WIDGET (item->canvas), calitem);
 
 	e_extensible_load_extensions (E_EXTENSIBLE (calitem));
 }
@@ -886,8 +890,7 @@ e_calendar_item_unmap		(GnomeCanvasItem *item)
 
 static void
 e_calendar_item_update		(GnomeCanvasItem *item,
-				 gdouble		 *affine,
-				 ArtSVP		 *clip_path,
+				 const cairo_matrix_t *i2c,
 				 gint		  flags)
 {
 	GnomeCanvasItemClass *item_class;
@@ -901,7 +904,7 @@ e_calendar_item_update		(GnomeCanvasItem *item,
 
 	item_class = GNOME_CANVAS_ITEM_CLASS (e_calendar_item_parent_class);
 	if (item_class->update != NULL)
-		item_class->update (item, affine, clip_path, flags);
+		item_class->update (item, i2c, flags);
 
 	calitem = E_CALENDAR_ITEM (item);
 	style = gtk_widget_get_style (GTK_WIDGET (item->canvas));
@@ -1153,7 +1156,6 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
 	GtkWidget *widget;
 	GtkStyle *style;
 	PangoFontDescription *font_desc;
-	GdkGC *fg_gc;
 	struct tm tmp_tm;
 	GdkRectangle clip_rect;
 	gint char_height, xthickness, ythickness, start_weekday;
@@ -1191,7 +1193,6 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
 		PANGO_PIXELS (pango_font_metrics_get_descent (font_metrics));
 	xthickness = style->xthickness;
 	ythickness = style->ythickness;
-	fg_gc = style->fg_gc[GTK_STATE_NORMAL];
 
 	pango_font_metrics_unref (font_metrics);
 
@@ -1247,9 +1248,12 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
 	start_weekday = (tmp_tm.tm_wday + 6) % 7;
 
 	if (month_x + max_x - clip_rect.x > 0) {
+                cairo_save (cr);
+
 		clip_rect.width = month_x + max_x - clip_rect.x;
 		clip_rect.height = text_y + char_height - clip_rect.y;
-		gdk_gc_set_clip_rectangle (fg_gc, &clip_rect);
+                gdk_cairo_rectangle (cr, &clip_rect);
+                cairo_clip (cr);
 
 		/* This is a strftime() format. %B = Month name, %Y = Year. */
 		e_utf8_strftime (buffer, sizeof (buffer), _("%B %Y"), &tmp_tm);
@@ -1263,10 +1267,13 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
 		text_x = (calitem->month_width - text_width) / 2;
 		text_x = MAX (min_x, text_x);
 
-		gdk_draw_layout (drawable, fg_gc,
-				 month_x + text_x,
-				 text_y,
-				 layout);
+                gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_NORMAL]);
+                cairo_move_to (cr,
+                               month_x + text_x,
+                               text_y);
+		pango_cairo_show_layout (cr, layout);
+
+                cairo_restore (cr);
 	}
 
 	/* Set the clip rectangle for the main month display. */
@@ -1284,7 +1291,8 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
 	clip_rect.width = clip_width;
 	clip_rect.height = clip_height;
 
-	gdk_gc_set_clip_rectangle (fg_gc, &clip_rect);
+        gdk_cairo_rectangle (cr, &clip_rect);
+        cairo_clip (cr);
 
 	/* Draw the day initials across the top of the month. */
 	min_cell_width = MAX (calitem->max_day_width, (calitem->max_digit_width * 2))
@@ -1319,13 +1327,13 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
 	pango_layout_set_font_description (layout, font_desc);
 	if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
 		text_x += (7-1) * calitem->cell_width;
-	gdk_gc_set_foreground (fg_gc, &style->text[GTK_STATE_ACTIVE]);
+        gdk_cairo_set_source_color (cr, &style->text[GTK_STATE_ACTIVE]);
 	for (day = 0; day < 7; day++) {
 		layout_set_day_text (calitem, layout, day_index);
-		gdk_draw_layout (drawable, fg_gc,
-				 text_x - calitem->day_widths [day_index],
-				 text_y,
-				 layout);
+                cairo_move_to (cr,
+                               text_x - calitem->day_widths[day_index],
+                               text_y);
+                pango_cairo_show_layout (cr, layout);
 		text_x += (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
 				? -calitem->cell_width : calitem->cell_width;
 		day_index++;
@@ -1347,7 +1355,6 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
                                           row, col, year, month, start_weekday,
                                           cells_x, cells_y);
 
-	gdk_gc_set_clip_rectangle (fg_gc, NULL);
 	g_object_unref (layout);
 	cairo_destroy (cr);
 }
@@ -1365,11 +1372,11 @@ get_digit_fomat ()
 	gint minor = 0;
 	gint revision = 0;
 
-	major = atoi (split [0]);
-	minor = atoi (split [1]);
+	major = atoi (split[0]);
+	minor = atoi (split[1]);
 
 	if (g_strv_length (split) > 2)
-		revision = atoi (split [2]);
+		revision = atoi (split[2]);
 	g_strfreev (split);
 
 	if (major > 2 || minor > 2 || (minor == 2 && revision > 2)) {
@@ -1397,7 +1404,6 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 	GtkWidget *widget;
 	GtkStyle *style;
 	PangoFontDescription *font_desc;
-	GdkGC *fg_gc;
 	GdkColor *bg_color, *fg_color, *box_color;
 	struct tm today_tm;
 	time_t t;
@@ -1427,7 +1433,6 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 	font_desc = calitem->font_desc;
 	if (!font_desc)
 		font_desc = style->font_desc;
-	fg_gc = style->fg_gc[GTK_STATE_NORMAL];
 
 	pango_context = gtk_widget_get_pango_context (widget);
 	font_metrics = pango_context_get_metrics (pango_context, font_desc,
@@ -1697,9 +1702,6 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 	pango_font_description_set_weight (font_desc, PANGO_WEIGHT_NORMAL);
 	pango_font_description_set_style (font_desc, PANGO_STYLE_NORMAL);
 
-	/* Reset the foreground color. */
-	gdk_gc_set_foreground (fg_gc, &style->fg[GTK_STATE_NORMAL]);
-
 	g_object_unref (layout);
 
 	pango_font_metrics_unref (font_metrics);
@@ -1754,13 +1756,11 @@ e_calendar_item_get_week_number	(ECalendarItem *calitem,
 /* This is supposed to return the nearest item the the point and the distance.
    Since we are the only item we just return ourself and 0 for the distance.
    This is needed so that we get button/motion events. */
-static double
+static GnomeCanvasItem *
 e_calendar_item_point (GnomeCanvasItem *item, gdouble x, gdouble y,
-			   gint cx, gint cy,
-			   GnomeCanvasItem **actual_item)
+		       gint cx, gint cy)
 {
-	*actual_item = item;
-	return 0.0;
+	return item;
 }
 
 static void
@@ -1775,7 +1775,7 @@ e_calendar_item_stop_selecting (ECalendarItem *calitem, guint32 time)
 
 	/* If the user selects the grayed dates before the first month or
 	   after the last month, we move backwards or forwards one month.
-	   The set_month() call should take care of updating the selection. */
+	   The set_month () call should take care of updating the selection. */
 	if (calitem->selection_end_month_offset == -1)
 		e_calendar_item_set_first_month (calitem, calitem->year,
 						 calitem->month - 1);
@@ -1866,24 +1866,24 @@ e_calendar_item_key_press_event (ECalendarItem *calitem, GdkEvent *event)
 
 	multi_selection = event->key.state & GDK_SHIFT_MASK;
 	switch (keyval) {
-	case GDK_Up:
+	case GDK_KEY_Up:
 		e_calendar_item_selection_add_days (calitem, -7,
 						    multi_selection);
 		break;
-	case GDK_Down:
+	case GDK_KEY_Down:
 		e_calendar_item_selection_add_days (calitem, 7,
 						    multi_selection);
 		break;
-	case GDK_Left:
+	case GDK_KEY_Left:
 		e_calendar_item_selection_add_days (calitem, -1,
 						    multi_selection);
 		break;
-	case GDK_Right:
+	case GDK_KEY_Right:
 		e_calendar_item_selection_add_days (calitem, 1,
 						    multi_selection);
 		break;
-	case GDK_space:
-	case GDK_Return:
+	case GDK_KEY_space:
+	case GDK_KEY_Return:
 		e_calendar_item_stop_selecting (calitem, event->key.time);
 		break;
 	default:
@@ -2550,7 +2550,7 @@ e_calendar_item_get_month_info	(ECalendarItem	*calitem,
 }
 
 void
-e_calendar_item_get_first_month(ECalendarItem	*calitem,
+e_calendar_item_get_first_month (ECalendarItem	*calitem,
 				gint		*year,
 				gint		*month)
 {
@@ -2598,7 +2598,7 @@ e_calendar_item_preserve_day_selection	(ECalendarItem	*calitem,
 
 /* This also handles values of month < 0 or > 11 by updating the year. */
 void
-e_calendar_item_set_first_month(ECalendarItem	*calitem,
+e_calendar_item_set_first_month (ECalendarItem	*calitem,
 				gint		 year,
 				gint		 month)
 {
@@ -2718,14 +2718,14 @@ e_calendar_item_set_max_days_sel       (ECalendarItem	*calitem,
 
 /* Get the maximum number of days before whole weeks are selected */
 gint
-e_calendar_item_get_days_start_week_sel(ECalendarItem	*calitem)
+e_calendar_item_get_days_start_week_sel (ECalendarItem	*calitem)
 {
 	return calitem->days_to_start_week_selection;
 }
 
 /* Set the maximum number of days before whole weeks are selected */
 void
-e_calendar_item_set_days_start_week_sel(ECalendarItem	*calitem,
+e_calendar_item_set_days_start_week_sel (ECalendarItem	*calitem,
 					gint            days)
 {
 	calitem->days_to_start_week_selection = days;
@@ -3096,8 +3096,8 @@ e_calendar_item_get_selection		(ECalendarItem	*calitem,
 
 static void
 e_calendar_item_set_selection_if_emission (ECalendarItem	*calitem,
-					   GDate		*start_date,
-					   GDate		*end_date,
+					   const GDate		*start_date,
+					   const GDate		*end_date,
 					   gboolean emission)
 {
 	gint start_year, start_month, start_day;
@@ -3199,8 +3199,8 @@ e_calendar_item_style_set (GtkWidget *widget, ECalendarItem *calitem)
 
 void
 e_calendar_item_set_selection (ECalendarItem	*calitem,
-			       GDate		*start_date,
-			       GDate		*end_date)
+			       const GDate	*start_date,
+			       const GDate	*end_date)
 {
 	/* If the user is in the middle of a selection, we must abort it. */
 	if (calitem->selecting) {
@@ -3470,7 +3470,7 @@ e_calendar_item_signal_emission_idle_cb	(gpointer data)
 
 	/* We ref the calitem & check in case it gets destroyed, since we
 	   were getting a free memory write here. */
-	g_object_ref((calitem));
+	g_object_ref ((calitem));
 
 	if (calitem->date_range_changed) {
 		calitem->date_range_changed = FALSE;
@@ -3482,7 +3482,7 @@ e_calendar_item_signal_emission_idle_cb	(gpointer data)
 		g_signal_emit (calitem, e_calendar_item_signals[SELECTION_CHANGED], 0);
 	}
 
-	g_object_unref((calitem));
+	g_object_unref ((calitem));
 
 	GDK_THREADS_LEAVE ();
 	return FALSE;
