@@ -42,8 +42,7 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#include <libgnomecanvas/gnome-canvas.h>
-#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
+#include <libgnomecanvas/libgnomecanvas.h>
 
 #include "gal-a11y-e-cell-registry.h"
 #include "gal-a11y-e-cell-text.h"
@@ -58,6 +57,10 @@
 #include "e-table.h"
 #include "e-cell-text.h"
 #include "e-table-item.h"
+
+/* backward-compatibility cruft */
+#include "e-util/gtk-compat.h"
+
 #define d(x)
 #define DO_SELECTION 1
 #define VIEW_TO_CELL(view) E_CELL_TEXT (((ECellView *)view)->ecell)
@@ -68,8 +71,6 @@
 #define e_table_item_leave_edit_(x) (e_table_item_leave_edit((x)))
 #endif
 
-#define ECT_CLASS(c) (E_CELL_TEXT_CLASS(GTK_OBJECT_GET_CLASS ((c))))
-
 /* This defines a line of text */
 struct line {
 	gchar *text;	/* Line's text UTF-8, it is a pointer into the text->text string */
@@ -102,7 +103,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint signals [LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL] = { 0 };
 
 static GdkAtom clipboard_atom = GDK_NONE;
 
@@ -123,9 +124,7 @@ typedef struct _CellEdit CellEdit;
 
 typedef struct {
 	ECellView    cell_view;
-	GdkGC       *gc;
 	GdkCursor *i_cursor;
-	GdkBitmap *stipple;		/* Stipple for text */
 
 	GnomeCanvas *canvas;
 
@@ -214,34 +213,10 @@ static void _delete_selection (ECellTextView *text_view);
 static PangoAttrList* build_attr_list (ECellTextView *text_view, gint row, gint text_length);
 static void update_im_cursor_location (ECellTextView *tv);
 
-gchar *
-e_cell_text_get_text (ECellText *cell, ETableModel *model, gint col, gint row)
-{
-	if (ECT_CLASS(cell)->get_text)
-		return ECT_CLASS(cell)->get_text (cell, model, col, row);
-	else
-		return NULL;
-}
-
-void
-e_cell_text_free_text (ECellText *cell, gchar *text)
-{
-	if (ECT_CLASS(cell)->free_text)
-		ECT_CLASS(cell)->free_text (cell, text);
-}
-
-void
-e_cell_text_set_value (ECellText *cell, ETableModel *model, gint col, gint row,
-		       const gchar *text)
-{
-	if (ECT_CLASS(cell)->set_value)
-		ECT_CLASS(cell)->set_value (cell, model, col, row, text);
-}
-
 static gchar *
 ect_real_get_text (ECellText *cell, ETableModel *model, gint col, gint row)
 {
-	return e_table_model_value_at(model, col, row);
+	return e_table_model_value_at (model, col, row);
 }
 
 static void
@@ -380,7 +355,7 @@ ect_kill_view (ECellView *ecv)
             (text_view->cell_view.kill_view_cb)(ecv, text_view->cell_view.kill_view_cb_data);
 
 	if (text_view->cell_view.kill_view_cb_data)
-	    g_list_free(text_view->cell_view.kill_view_cb_data);
+	    g_list_free (text_view->cell_view.kill_view_cb_data);
 
 	g_free (text_view);
 }
@@ -395,7 +370,6 @@ ect_realize (ECellView *ecell_view)
 	GdkWindow *window;
 
 	window = gtk_widget_get_window (GTK_WIDGET (text_view->canvas));
-	text_view->gc = gdk_gc_new (window);
 
 	text_view->i_cursor = gdk_cursor_new (GDK_XTERM);
 
@@ -413,16 +387,10 @@ ect_unrealize (ECellView *ecv)
 	ECellText *ect = (ECellText*) ecv->ecell;
 	GdkColormap *colormap;
 
-	g_object_unref (text_view->gc);
-	text_view->gc = NULL;
-
 	if (text_view->edit) {
 		ect_cancel_edit (text_view);
 	}
 
-	if (text_view->stipple)
-		g_object_unref (text_view->stipple);
-
 	gdk_cursor_unref (text_view->i_cursor);
 
 	if (ect->colors) {
@@ -464,13 +432,13 @@ build_attr_list (ECellTextView *text_view, gint row, gint text_length)
 
 	bold = ect->bold_column >= 0 &&
 		row >= 0 &&
-		e_table_model_value_at(ecell_view->e_table_model, ect->bold_column, row);
+		e_table_model_value_at (ecell_view->e_table_model, ect->bold_column, row);
 	strikeout = ect->strikeout_column >= 0 &&
 		row >= 0 &&
-		e_table_model_value_at(ecell_view->e_table_model, ect->strikeout_column, row);
+		e_table_model_value_at (ecell_view->e_table_model, ect->strikeout_column, row);
 	underline = ect->underline_column >= 0 &&
 		row >= 0 &&
-		e_table_model_value_at(ecell_view->e_table_model, ect->underline_column, row);
+		e_table_model_value_at (ecell_view->e_table_model, ect->underline_column, row);
 
 	if (bold || strikeout || underline) {
 		if (bold) {
@@ -509,7 +477,7 @@ layout_with_preedit (ECellTextView *text_view, gint row, const gchar *text, gint
 	gchar *preedit_string = NULL;
 	gint preedit_length = 0;
 	gint text_length = strlen (text);
-	gint mlen = MIN(edit->selection_start,text_length);
+	gint mlen = MIN (edit->selection_start,text_length);
 
 	gtk_im_context_get_preedit_string (edit->im_context,
 					&preedit_string,&preedit_attrs,
@@ -581,7 +549,7 @@ build_layout (ECellTextView *text_view, gint row, const gchar *text, gint width)
 
 	context = pango_layout_get_context (layout);
 
-	font_options = get_font_options();
+	font_options = get_font_options ();
 	pango_cairo_context_set_font_options (context, font_options);
 	cairo_font_options_destroy (font_options);
 	pango_layout_context_changed (layout);
@@ -647,9 +615,9 @@ generate_layout (ECellTextView *text_view, gint model_col, gint view_col, gint r
 	}
 
 	if (row >= 0) {
-		gchar *temp = e_cell_text_get_text(ect, ecell_view->e_table_model, model_col, row);
+		gchar *temp = e_cell_text_get_text (ect, ecell_view->e_table_model, model_col, row);
 		layout = build_layout (text_view, row, temp ? temp : "?", width);
-		e_cell_text_free_text(ect, temp);
+		e_cell_text_free_text (ect, temp);
 	} else
 		layout = build_layout (text_view, row, "Mumbo Jumbo", width);
 
@@ -657,16 +625,22 @@ generate_layout (ECellTextView *text_view, gint model_col, gint view_col, gint r
 }
 
 static void
-draw_pango_rectangle (GdkDrawable *drawable, GdkGC *gc, gint x1, gint y1, PangoRectangle rect)
+draw_cursor (cairo_t *cr, gint x1, gint y1, PangoRectangle rect)
 {
-	gint width = rect.width / PANGO_SCALE;
-	gint height = rect.height / PANGO_SCALE;
-	if (width <= 0)
-		width = 1;
-	if (height <= 0)
-		height = 1;
-	gdk_draw_rectangle (drawable, gc, TRUE,
-			    x1 + rect.x / PANGO_SCALE, y1 + rect.y / PANGO_SCALE, width, height);
+	gdouble scaled_x;
+	gdouble scaled_y;
+	gdouble scaled_height;
+
+	/* Pango stores each cursor position as a zero-width rectangle. */
+	scaled_x = x1 + ((gdouble) rect.x) / PANGO_SCALE;
+	scaled_y = y1 + ((gdouble) rect.y) / PANGO_SCALE;
+	scaled_height = ((gdouble) rect.height) / PANGO_SCALE;
+
+	/* Adding 0.5 to scaled_x gives a sharp, one-pixel line. */
+	cairo_move_to (cr, scaled_x + 0.5, scaled_y);
+	cairo_line_to (cr, scaled_x + 0.5, scaled_y + scaled_height);
+	cairo_set_line_width (cr, 1);
+	cairo_stroke (cr);
 }
 
 static gboolean
@@ -732,23 +706,24 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 	ECellText *ect = E_CELL_TEXT (ecell_view->ecell);
 	CellEdit *edit = text_view->edit;
 	gboolean selected;
-	GdkColor *foreground;
 	GtkWidget *canvas = GTK_WIDGET (text_view->canvas);
-	GdkRectangle clip_rect;
 	GtkStyle *style;
 	gint x_origin, y_origin, vspacing;
+        cairo_t *cr;
 
 	style = gtk_widget_get_style (canvas);
 
 	selected = flags & E_CELL_SELECTED;
 
+        cr = gdk_cairo_create (drawable);
+
 	if (selected) {
 		if (gtk_widget_has_focus (canvas))
-			foreground = &style->fg[GTK_STATE_SELECTED];
+			gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_SELECTED]);
 		else
-			foreground = &style->fg[GTK_STATE_ACTIVE];
+			gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_ACTIVE]);
 	} else {
-		foreground = &style->text[GTK_STATE_NORMAL];
+		gdk_cairo_set_source_color (cr, &style->text[GTK_STATE_NORMAL]);
 
 		if (ect->color_column != -1) {
 			gchar *color_spec;
@@ -759,12 +734,10 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 			cell_foreground = e_cell_text_get_color (text_view,
 								 color_spec);
 			if (cell_foreground)
-				foreground = cell_foreground;
+				gdk_cairo_set_source_color (cr, cell_foreground);
 		}
 	}
 
-	gdk_gc_set_foreground (text_view->gc, foreground);
-
 	vspacing = get_vertical_spacing (canvas);
 
 	x1 += 4;
@@ -775,13 +748,8 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 	x_origin = x1 + ect->x + text_view->xofs - (edit ? edit->xofs_edit : 0);
 	y_origin = y1 + ect->y + text_view->yofs - (edit ? edit->yofs_edit : 0);
 
-	clip_rect.x = x1;
-	clip_rect.y = y1;
-	clip_rect.width = x2 - x1;
-	clip_rect.height = y2 - y1;
-
-	gdk_gc_set_clip_rectangle (text_view->gc, &clip_rect);
-	/*	clip_rect = &rect;*/
+        cairo_rectangle (cr, x1, y1, x2 - x1, y2 - y1);
+        cairo_clip (cr);
 
 	layout = generate_layout (text_view, model_col, view_col, row, x2 - x1);
 
@@ -789,91 +757,57 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 		layout = layout_with_preedit  (text_view, row, edit->text ? edit->text : "?",  x2 - x1);
 	}
 
-	gdk_draw_layout (drawable, text_view->gc,
-			 x_origin, y_origin,
-			 layout);
+        cairo_move_to (cr, x_origin, y_origin);
+	pango_cairo_show_layout (cr, layout);
 
 	if (edit && edit->view_col == view_col && edit->row == row) {
 		if (edit->selection_start != edit->selection_end) {
-			gint start_index, end_index;
-			PangoLayoutLine *line;
-			gint *ranges;
-			gint n_ranges, i;
-			PangoRectangle logical_rect;
-			GdkRegion *clip_region = gdk_region_new ();
-			GdkRegion *rect_region;
-			GdkGC *selection_gc;
-			GdkGC *text_gc;
+			GdkRegion *clip_region;
+                        gint indices[2];
+                        GtkStateType state;
 
-			start_index = MIN (edit->selection_start, edit->selection_end);
-			end_index = edit->selection_start ^ edit->selection_end ^ start_index;
+                        state = edit->has_selection ? GTK_STATE_SELECTED : GTK_STATE_ACTIVE;
 
-			if (edit->has_selection) {
-				selection_gc = style->base_gc[GTK_STATE_SELECTED];
-				text_gc = style->text_gc[GTK_STATE_SELECTED];
-			} else {
-				selection_gc = style->base_gc [GTK_STATE_ACTIVE];
-				text_gc = style->text_gc[GTK_STATE_ACTIVE];
-			}
-
-			gdk_gc_set_clip_rectangle (selection_gc, &clip_rect);
-
-			line = pango_layout_get_lines (layout)->data;
-
-			pango_layout_line_get_x_ranges (line, start_index, end_index, &ranges, &n_ranges);
-
-			pango_layout_get_extents (layout, NULL, &logical_rect);
-
-			for (i=0; i < n_ranges; i++) {
-				GdkRectangle sel_rect;
-
-				sel_rect.x = x_origin + ranges[2*i] / PANGO_SCALE;
-				sel_rect.y = y_origin;
-				sel_rect.width = (ranges[2*i + 1] - ranges[2*i]) / PANGO_SCALE;
-				sel_rect.height = logical_rect.height / PANGO_SCALE;
-
-				gdk_draw_rectangle (drawable, selection_gc, TRUE,
-						    sel_rect.x, sel_rect.y, sel_rect.width, sel_rect.height);
-
-				gdk_region_union_with_rect (clip_region, &sel_rect);
-			}
-
-			rect_region = gdk_region_rectangle (&clip_rect);
-			gdk_region_intersect (clip_region, rect_region);
-			gdk_region_destroy (rect_region);
-
-			gdk_gc_set_clip_region (text_gc, clip_region);
-			gdk_draw_layout (drawable, text_gc,
-					 x_origin, y_origin,
-					 layout);
-			gdk_gc_set_clip_region (text_gc, NULL);
-			gdk_gc_set_clip_region (selection_gc, NULL);
+			indices[0] = MIN (edit->selection_start, edit->selection_end);
+			indices[1] = MAX (edit->selection_start, edit->selection_end);
 
+                        clip_region = gdk_pango_layout_get_clip_region (layout,
+                                                                        x_origin, y_origin,
+                                                                        indices, 1);
+                        gdk_cairo_region (cr, clip_region);
+                        cairo_clip (cr);
 			gdk_region_destroy (clip_region);
-			g_free (ranges);
+
+                        gdk_cairo_set_source_color (cr, &style->base[state]);
+                        cairo_paint (cr);
+
+                        gdk_cairo_set_source_color (cr, &style->text[state]);
+                        cairo_move_to (cr, x_origin, y_origin);
+                        pango_cairo_show_layout (cr, layout);
 		} else {
 			if (edit->show_cursor) {
 				PangoRectangle strong_pos, weak_pos;
 				pango_layout_get_cursor_pos (layout, edit->selection_start + edit->preedit_length, &strong_pos, &weak_pos);
 
-				draw_pango_rectangle (drawable, text_view->gc, x_origin, y_origin, strong_pos);
+				draw_cursor (cr, x_origin, y_origin, strong_pos);
 				if (strong_pos.x != weak_pos.x ||
 				    strong_pos.y != weak_pos.y ||
 				    strong_pos.width != weak_pos.width ||
 				    strong_pos.height != weak_pos.height)
-					draw_pango_rectangle (drawable, text_view->gc, x_origin, y_origin, weak_pos);
+					draw_cursor (cr, x_origin, y_origin, weak_pos);
 			}
 		}
 	}
 
 	g_object_unref (layout);
+        cairo_destroy (cr);
 }
 
 /*
  * Get the background color
  */
 static gchar *
-ect_get_bg_color(ECellView *ecell_view, gint row)
+ect_get_bg_color (ECellView *ecell_view, gint row)
 {
 	ECellText *ect = E_CELL_TEXT (ecell_view->ecell);
 	gchar *color_spec;
@@ -922,7 +856,7 @@ ect_event (ECellView *ecell_view, GdkEvent *event, gint model_col, gint view_col
 	CellEdit *edit = text_view->edit;
 	GtkWidget *canvas = GTK_WIDGET (text_view->canvas);
 	gint return_val = 0;
-	d(gboolean press = FALSE);
+	d (gboolean press = FALSE);
 
 	if (!(flags & E_CELL_EDITING))
 		return 0;
@@ -999,7 +933,7 @@ ect_event (ECellView *ecell_view, GdkEvent *event, gint model_col, gint view_col
 				return 1;
 		}
 
-		if (event->key.keyval == GDK_Escape) {
+		if (event->key.keyval == GDK_KEY_Escape) {
 			/* if not changed, then pass this even to parent */
 			return_val = text_view->edit != NULL && text_view->edit->text && text_view->edit->old_text && 0 != strcmp (text_view->edit->text, text_view->edit->old_text);
 			ect_cancel_edit (text_view);
@@ -1017,7 +951,7 @@ ect_event (ECellView *ecell_view, GdkEvent *event, gint model_col, gint view_col
 		if (edit_display) {
 			GdkEventKey key = event->key;
 			if (key.type == GDK_KEY_PRESS &&
-			    (key.keyval == GDK_KP_Enter || key.keyval == GDK_Return)) {
+			    (key.keyval == GDK_KEY_KP_Enter || key.keyval == GDK_KEY_Return)) {
 				/* stop editing when it's only GDK_KEY_PRESS event */
 				e_table_item_leave_edit_ (text_view->cell_view.e_table_item_view);
 			} else {
@@ -1047,7 +981,7 @@ ect_event (ECellView *ecell_view, GdkEvent *event, gint model_col, gint view_col
 
 		break;
 	case GDK_BUTTON_PRESS: /* Fall Through */
-		d(press = TRUE);
+		d (press = TRUE);
 	case GDK_BUTTON_RELEASE:
 		d(g_print ("%s: %s\n", __FUNCTION__, press ? "GDK_BUTTON_PRESS" : "GDK_BUTTON_RELEASE"));
 		event->button.x -= 4;
@@ -1183,7 +1117,7 @@ ect_enter_edit (ECellView *ecell_view, gint model_col, gint view_col, gint row)
 {
 	ECellTextView *text_view = (ECellTextView *) ecell_view;
 	CellEdit *edit;
-	ECellText *ect = E_CELL_TEXT(ecell_view->ecell);
+	ECellText *ect = E_CELL_TEXT (ecell_view->ecell);
 	gchar *temp;
 
 	edit = g_new0 (CellEdit, 1);
@@ -1233,15 +1167,15 @@ ect_enter_edit (ECellView *ecell_view, gint model_col, gint view_col, gint row)
 	edit->pointer_in = FALSE;
 	edit->default_cursor_shown = TRUE;
 
-	temp = e_cell_text_get_text(ect, ecell_view->e_table_model, model_col, row);
+	temp = e_cell_text_get_text (ect, ecell_view->e_table_model, model_col, row);
 	edit->old_text = g_strdup (temp);
-	e_cell_text_free_text(ect, temp);
+	e_cell_text_free_text (ect, temp);
 	edit->text = g_strdup (edit->old_text);
 
 #if 0
 	if (edit->pointer_in) {
 		if (edit->default_cursor_shown) {
-			gdk_window_set_cursor (GTK_WIDGET(item->canvas)->window, text_view->i_cursor);
+			gdk_window_set_cursor (GTK_WIDGET (item->canvas)->window, text_view->i_cursor);
 			edit->default_cursor_shown = FALSE;
 		}
 	}
@@ -1341,9 +1275,9 @@ ect_print (ECellView *ecell_view, GtkPrintContext *context,
 	PangoLayout *layout;
 	PangoContext *pango_context;
 	PangoFontMetrics *font_metrics;
-	ECellText *ect = E_CELL_TEXT(ecell_view->ecell);
+	ECellText *ect = E_CELL_TEXT (ecell_view->ecell);
 	ECellTextView *ectView = (ECellTextView *)ecell_view;
-	GtkWidget *canvas = GTK_WIDGET(ectView->canvas);
+	GtkWidget *canvas = GTK_WIDGET (ectView->canvas);
 	GtkStyle *style;
 	PangoDirection dir;
 	gboolean strikeout, underline;
@@ -1352,7 +1286,7 @@ ect_print (ECellView *ecell_view, GtkPrintContext *context,
 	gdouble ty, ly, text_width = 0.0, text_height = 0.0;
 
 	cr = gtk_print_context_get_cairo_context (context);
-	string = e_cell_text_get_text(ect, ecell_view->e_table_model, model_col, row);
+	string = e_cell_text_get_text (ect, ecell_view->e_table_model, model_col, row);
 
 	cairo_save (cr);
 	layout = gtk_print_context_create_pango_layout (context);
@@ -1362,15 +1296,15 @@ ect_print (ECellView *ecell_view, GtkPrintContext *context,
 	pango_layout_set_text (layout, string, -1);
 	get_font_size (layout, font_des, string, &text_width, &text_height);
 
-	cairo_move_to(cr, 2, 2);
+	cairo_move_to (cr, 2, 2);
 	cairo_rectangle (cr, 2, 2, width + 2, height + 2);
-	cairo_clip(cr);
+	cairo_clip (cr);
 
 	style = gtk_widget_get_style (canvas);
 	pango_context = gtk_widget_get_pango_context (canvas);
 	font_metrics = pango_context_get_metrics (
 		pango_context, style->font_desc,
-		pango_context_get_language(pango_context));
+		pango_context_get_language (pango_context));
 	ty =  (gdouble)(text_height -
 		pango_font_metrics_get_ascent (font_metrics) -
 		pango_font_metrics_get_descent (font_metrics)) / 2.0 /(gdouble)PANGO_SCALE;
@@ -1378,9 +1312,9 @@ ect_print (ECellView *ecell_view, GtkPrintContext *context,
 	strikeout = ect->strikeout_column >= 0 && row >= 0 &&
 		e_table_model_value_at (ecell_view->e_table_model, ect->strikeout_column, row);
 	underline = ect->underline_column >= 0 && row >= 0 &&
-		e_table_model_value_at(ecell_view->e_table_model, ect->underline_column, row);
+		e_table_model_value_at (ecell_view->e_table_model, ect->underline_column, row);
 
-	dir = pango_find_base_dir (string, strlen(string));
+	dir = pango_find_base_dir (string, strlen (string));
 
 	if (underline) {
 		ly = ty + (gdouble)pango_font_metrics_get_underline_position (font_metrics)/(gdouble)PANGO_SCALE;
@@ -1413,15 +1347,15 @@ ect_print (ECellView *ecell_view, GtkPrintContext *context,
 			cairo_stroke (cr);
 	}
 
-	cairo_move_to(cr, 2, text_height- 5);
+	cairo_move_to (cr, 2, text_height- 5);
 	pango_layout_set_width (layout, (width - 4)*PANGO_SCALE);
 	pango_layout_set_wrap (layout, PANGO_WRAP_CHAR);
-	pango_cairo_show_layout(cr, layout);
+	pango_cairo_show_layout (cr, layout);
 	cairo_restore (cr);
 
 	pango_font_description_free (font_des);
 	g_object_unref (layout);
-	e_cell_text_free_text(ect, string);
+	e_cell_text_free_text (ect, string);
 }
 
 static gdouble
@@ -1438,12 +1372,12 @@ ect_print_height (ECellView *ecell_view, GtkPrintContext *context,
 	 */
 	PangoFontDescription *font_des;
 	PangoLayout *layout;
-	ECellText *ect = E_CELL_TEXT(ecell_view->ecell);
+	ECellText *ect = E_CELL_TEXT (ecell_view->ecell);
 	gchar *string;
 	gdouble text_width = 0.0, text_height = 0.0;
 	gint lines=1;
 
-	string = e_cell_text_get_text(ect, ecell_view->e_table_model, model_col, row);
+	string = e_cell_text_get_text (ect, ecell_view->e_table_model, model_col, row);
 
 	layout = gtk_print_context_create_pango_layout (context);
 	font_des = pango_font_description_from_string ("sans 10"); /* fix me font hardcoded */
@@ -1506,9 +1440,6 @@ ect_max_width_by_row (ECellView *ecell_view,
 	return width + 8;
 }
 
-/*
- * GtkObject::destroy method
- */
 static void
 ect_finalize (GObject *object)
 {
@@ -1518,6 +1449,7 @@ ect_finalize (GObject *object)
 
 	G_OBJECT_CLASS (e_cell_text_parent_class)->finalize (object);
 }
+
 /* Set_arg handler for the text item */
 static void
 ect_set_property (GObject *object,
@@ -1638,7 +1570,7 @@ e_cell_text_class_init (ECellTextClass *klass)
 	object_class->get_property = ect_get_property;
 	object_class->set_property = ect_set_property;
 
-	signals [TEXT_INSERTED] =
+	signals[TEXT_INSERTED] =
 		g_signal_new ("text_inserted",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_FIRST,
@@ -1649,7 +1581,7 @@ e_cell_text_class_init (ECellTextClass *klass)
 			      G_TYPE_POINTER, G_TYPE_INT, G_TYPE_INT,
 			      G_TYPE_INT, G_TYPE_INT);
 
-	signals [TEXT_DELETED] =
+	signals[TEXT_DELETED] =
 		g_signal_new ("text_deleted",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_FIRST,
@@ -1714,7 +1646,7 @@ e_cell_text_class_init (ECellTextClass *klass)
 		}
 	}
 
-	gal_a11y_e_cell_registry_add_cell_type (NULL, E_CELL_TEXT_TYPE, gal_a11y_e_cell_text_new);
+	gal_a11y_e_cell_registry_add_cell_type (NULL, E_TYPE_CELL_TEXT, gal_a11y_e_cell_text_new);
 }
 
 /* IM Context Callbacks */
@@ -1809,7 +1741,7 @@ e_cell_text_commit_cb (GtkIMContext *context,
 		command.action = E_TEP_INSERT;
 		command.position = E_TEP_SELECTION;
 		command.string = (gchar *)str;
-		command.value = strlen(str);
+		command.value = strlen (str);
 		e_cell_text_view_command (edit->tep, &command, edit);
 	}
 
@@ -1872,28 +1804,6 @@ e_cell_text_init (ECellText *ect)
 	ect->editable = TRUE;
 }
 
-/**
- * e_cell_text_construct:
- * @cell: The cell to construct
- * @fontname: this param is no longer used, but left here for api stability
- * @justify: Justification of the string in the cell
- *
- * constructs the ECellText.  To be used by subclasses and language
- * bindings.
- *
- * Returns: The ECellText.
- */
-ECell *
-e_cell_text_construct (ECellText *cell, const gchar *fontname, GtkJustification justify)
-{
-	if (!cell)
-		return E_CELL(NULL);
-	if (fontname)
-		cell->font_name = g_strdup (fontname);
-	cell->justify = justify;
-	return E_CELL(cell);
-}
-
 /**
  * e_cell_text_new:
  * @fontname: this param is no longer used, but left here for api stability
@@ -1922,13 +1832,87 @@ e_cell_text_construct (ECellText *cell, const gchar *fontname, GtkJustification
 ECell *
 e_cell_text_new (const gchar *fontname, GtkJustification justify)
 {
-	ECellText *ect = g_object_new (E_CELL_TEXT_TYPE, NULL);
+	ECellText *ect = g_object_new (E_TYPE_CELL_TEXT, NULL);
 
-	e_cell_text_construct(ect, fontname, justify);
+	e_cell_text_construct (ect, fontname, justify);
 
 	return (ECell *) ect;
 }
 
+/**
+ * e_cell_text_construct:
+ * @cell: The cell to construct
+ * @fontname: this param is no longer used, but left here for api stability
+ * @justify: Justification of the string in the cell
+ *
+ * constructs the ECellText.  To be used by subclasses and language
+ * bindings.
+ *
+ * Returns: The ECellText.
+ */
+ECell *
+e_cell_text_construct (ECellText *cell,
+                       const gchar *fontname,
+                       GtkJustification justify)
+{
+	if (!cell)
+		return E_CELL (NULL);
+	if (fontname)
+		cell->font_name = g_strdup (fontname);
+	cell->justify = justify;
+	return E_CELL (cell);
+}
+
+gchar *
+e_cell_text_get_text (ECellText *cell,
+                      ETableModel *model,
+                      gint col,
+                      gint row)
+{
+	ECellTextClass *class;
+
+	g_return_val_if_fail (E_IS_CELL_TEXT (cell), NULL);
+
+	class = E_CELL_TEXT_GET_CLASS (cell);
+	if (class->get_text == NULL)
+		return NULL;
+
+	return class->get_text (cell, model, col, row);
+}
+
+void
+e_cell_text_free_text (ECellText *cell,
+                       gchar *text)
+{
+	ECellTextClass *class;
+
+	g_return_if_fail (E_IS_CELL_TEXT (cell));
+
+	class = E_CELL_TEXT_GET_CLASS (cell);
+	if (class->free_text == NULL)
+		return;
+
+	class->free_text (cell, text);
+}
+
+void
+e_cell_text_set_value (ECellText *cell,
+                       ETableModel *model,
+                       gint col,
+                       gint row,
+                       const gchar *text)
+{
+	ECellTextClass *class;
+
+	g_return_if_fail (E_IS_CELL_TEXT (cell));
+
+	class = E_CELL_TEXT_GET_CLASS (cell);
+	if (class->set_value == NULL)
+		return;
+
+	class->set_value (cell, model, col, row, text);
+}
+
 /* fixme: Handle Font attributes */
 /* position is in BYTES */
 
@@ -2188,7 +2172,7 @@ _get_position (ECellTextView *text_view, ETextEventProcessorCommand *command)
 		return edit->selection_end;
 	}
 
-	g_return_val_if_reached(0);
+	g_return_val_if_reached (0);
 
 	return 0; /* Kill warning */
 }
@@ -2230,7 +2214,7 @@ _insert (ECellTextView *text_view, const gchar *string, gint value)
 
 	if (value <= 0) return;
 
-	edit->selection_start = MIN (strlen(edit->text), edit->selection_start);
+	edit->selection_start = MIN (strlen (edit->text), edit->selection_start);
 
 	temp = g_new (gchar, strlen (edit->text) + value + 1);
 
@@ -2330,8 +2314,8 @@ e_cell_text_view_command (ETextEventProcessor *tep, ETextEventProcessorCommand *
 		break;
 	case E_TEP_SELECT:
 		edit->selection_end = _get_position (text_view, command);
-		sel_start = MIN(edit->selection_start, edit->selection_end);
-		sel_end = MAX(edit->selection_start, edit->selection_end);
+		sel_start = MIN (edit->selection_start, edit->selection_end);
+		sel_end = MAX (edit->selection_start, edit->selection_end);
 		if (sel_start != sel_end) {
 			e_cell_text_view_supply_selection (edit, command->time, GDK_SELECTION_PRIMARY,
 							   edit->text + sel_start,
@@ -2365,8 +2349,8 @@ e_cell_text_view_command (ETextEventProcessor *tep, ETextEventProcessorCommand *
 		change = TRUE;
 		break;
 	case E_TEP_COPY:
-		sel_start = MIN(edit->selection_start, edit->selection_end);
-		sel_end = MAX(edit->selection_start, edit->selection_end);
+		sel_start = MIN (edit->selection_start, edit->selection_end);
+		sel_end = MAX (edit->selection_start, edit->selection_end);
 		if (sel_start != sel_end) {
 			e_cell_text_view_supply_selection (edit, command->time, clipboard_atom,
 							   edit->text + sel_start,
@@ -2500,7 +2484,7 @@ _get_tep (CellEdit *edit)
 		edit->tep = e_text_event_processor_emacs_like_new ();
 		g_signal_connect (edit->tep,
 				  "command",
-				  G_CALLBACK(e_cell_text_view_command),
+				  G_CALLBACK (e_cell_text_view_command),
 				  (gpointer) edit);
 	}
 }
@@ -2564,15 +2548,17 @@ e_cell_text_get_color (ECellTextView *cell_view, gchar *color_spec)
  */
 gboolean
 e_cell_text_set_selection (ECellView *cell_view,
-			   gint col,
-			   gint row,
-			   gint start,
-			   gint end)
+                           gint col,
+                           gint row,
+                           gint start,
+                           gint end)
 {
 	ECellTextView *ectv;
 	CellEdit *edit;
 	ETextEventProcessorCommand command1, command2;
 
+	g_return_val_if_fail (cell_view != NULL, FALSE);
+
 	ectv = (ECellTextView *)cell_view;
 	edit = ectv->edit;
 	if (!edit)
@@ -2612,14 +2598,16 @@ e_cell_text_set_selection (ECellView *cell_view,
  */
 gboolean
 e_cell_text_get_selection (ECellView *cell_view,
-			   gint col,
-			   gint row,
-			   gint *start,
-			   gint *end)
+                           gint col,
+                           gint row,
+                           gint *start,
+                           gint *end)
 {
 	ECellTextView *ectv;
 	CellEdit *edit;
 
+	g_return_val_if_fail (cell_view != NULL, FALSE);
+
 	ectv = (ECellTextView *)cell_view;
 	edit = ectv->edit;
 	if (!edit)
@@ -2646,12 +2634,16 @@ e_cell_text_get_selection (ECellView *cell_view,
  * This API is most likely to be used by a11y implementations.
  */
 void
-e_cell_text_copy_clipboard (ECellView *cell_view, gint col, gint row)
+e_cell_text_copy_clipboard (ECellView *cell_view,
+                            gint col,
+                            gint row)
 {
 	ECellTextView *ectv;
 	CellEdit *edit;
 	ETextEventProcessorCommand command;
 
+	g_return_if_fail (cell_view != NULL);
+
 	ectv = (ECellTextView *)cell_view;
 	edit = ectv->edit;
 	if (!edit)
@@ -2676,12 +2668,16 @@ e_cell_text_copy_clipboard (ECellView *cell_view, gint col, gint row)
  * This API is most likely to be used by a11y implementations.
  */
 void
-e_cell_text_paste_clipboard (ECellView *cell_view, gint col, gint row)
+e_cell_text_paste_clipboard (ECellView *cell_view,
+                             gint col,
+                             gint row)
 {
 	ECellTextView *ectv;
 	CellEdit *edit;
 	ETextEventProcessorCommand command;
 
+	g_return_if_fail (cell_view != NULL);
+
 	ectv = (ECellTextView *)cell_view;
 	edit = ectv->edit;
 	if (!edit)
@@ -2706,12 +2702,16 @@ e_cell_text_paste_clipboard (ECellView *cell_view, gint col, gint row)
  * This API is most likely to be used by a11y implementations.
  */
 void
-e_cell_text_delete_selection (ECellView *cell_view, gint col, gint row)
+e_cell_text_delete_selection (ECellView *cell_view,
+                              gint col,
+                              gint row)
 {
 	ECellTextView *ectv;
 	CellEdit *edit;
 	ETextEventProcessorCommand command;
 
+	g_return_if_fail (cell_view != NULL);
+
 	ectv = (ECellTextView *)cell_view;
 	edit = ectv->edit;
 	if (!edit)
@@ -2739,12 +2739,16 @@ e_cell_text_delete_selection (ECellView *cell_view, gint col, gint row)
  * This API is most likely to be used by a11y implementations.
  */
 gchar *
-e_cell_text_get_text_by_view (ECellView *cell_view, gint col, gint row)
+e_cell_text_get_text_by_view (ECellView *cell_view,
+                              gint col,
+                              gint row)
 {
 	ECellTextView *ectv;
 	CellEdit *edit;
 	gchar	*ret, *model_text;
 
+	g_return_val_if_fail (cell_view != NULL, NULL);
+
 	ectv = (ECellTextView *)cell_view;
 	edit = ectv->edit;
 
