@@ -44,7 +44,6 @@
 #include <glib-object.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
 
 #include "gal-a11y-e-text.h"
 #include "misc/e-canvas.h"
@@ -53,10 +52,12 @@
 #include <glib/gi18n.h>
 #include "e-util/e-text-event-processor-emacs-like.h"
 #include "e-util/e-util.h"
-#include "e-util/gtk-compat.h"
 
 #include "e-text.h"
 
+/* backward-compatibility cruft */
+#include "e-util/gtk-compat.h"
+
 G_DEFINE_TYPE (EText, e_text, GNOME_TYPE_CANVAS_ITEM)
 
 #define BORDER_INDENT 3
@@ -92,7 +93,6 @@ enum {
 	PROP_FILL_COLOR,
 	PROP_FILL_COLOR_GDK,
 	PROP_FILL_COLOR_RGBA,
-	PROP_FILL_STIPPLE,
 	PROP_TEXT_WIDTH,
 	PROP_TEXT_HEIGHT,
 	PROP_EDITABLE,
@@ -228,10 +228,6 @@ e_text_dispose (GObject *object)
 	g_free (text->revert);
 	text->revert = NULL;
 
-	if (text->stipple)
-		g_object_unref (text->stipple);
-	text->stipple = NULL;
-
 	if (text->timeout_id) {
 		g_source_remove (text->timeout_id);
 		text->timeout_id = 0;
@@ -538,50 +534,6 @@ get_bounds (EText *text, gdouble *px1, gdouble *py1, gdouble *px2, gdouble *py2)
 	text->clip_cwidth = clip_width * item->canvas->pixels_per_unit;
 	text->clip_cheight = clip_height * item->canvas->pixels_per_unit;
 
-	/* Anchor text */
-
-	switch (text->anchor) {
-	case GTK_ANCHOR_NW:
-	case GTK_ANCHOR_W:
-	case GTK_ANCHOR_SW:
-		break;
-
-	case GTK_ANCHOR_N:
-	case GTK_ANCHOR_CENTER:
-	case GTK_ANCHOR_S:
-		text->cx -= text->width / 2;
-		text->clip_cx -= text->clip_cwidth / 2;
-		break;
-
-	case GTK_ANCHOR_NE:
-	case GTK_ANCHOR_E:
-	case GTK_ANCHOR_SE:
-		text->cx -= text->width;
-		text->clip_cx -= text->clip_cwidth;
-		break;
-	}
-
-	switch (text->anchor) {
-	case GTK_ANCHOR_NW:
-	case GTK_ANCHOR_N:
-	case GTK_ANCHOR_NE:
-		break;
-
-	case GTK_ANCHOR_W:
-	case GTK_ANCHOR_CENTER:
-	case GTK_ANCHOR_E:
-		text->cy -= text->height / 2;
-		text->clip_cy -= text->clip_cheight / 2;
-		break;
-
-	case GTK_ANCHOR_SW:
-	case GTK_ANCHOR_S:
-	case GTK_ANCHOR_SE:
-		text->cy -= text->height;
-		text->clip_cy -= text->clip_cheight;
-		break;
-	}
-
 	text->text_cx = text->cx;
 	text->text_cy = text->cy;
 
@@ -652,36 +604,6 @@ split_into_lines (EText *text)
 	text->num_lines = pango_layout_get_line_count (text->layout);
 }
 
-/* Convenience function to set the text's GC's foreground color */
-static void
-set_text_gc_foreground (EText *text)
-{
-	if (!text->gc)
-		return;
-
-	gdk_gc_set_foreground (text->gc, &text->color);
-}
-
-/* Sets the stipple pattern for the text */
-static void
-set_stipple (EText *text, GdkBitmap *stipple, gint reconfigure)
-{
-	if (text->stipple && !reconfigure)
-		g_object_unref (text->stipple);
-
-	text->stipple = stipple;
-	if (stipple && !reconfigure)
-		g_object_ref (stipple);
-
-	if (text->gc) {
-		if (stipple) {
-			gdk_gc_set_stipple (text->gc, stipple);
-			gdk_gc_set_fill (text->gc, GDK_STIPPLED);
-		} else
-			gdk_gc_set_fill (text->gc, GDK_SOLID);
-	}
-}
-
 /* Set_arg handler for the text item */
 static void
 e_text_set_property (GObject *object,
@@ -693,7 +615,6 @@ e_text_set_property (GObject *object,
 	EText *text;
 	GdkColor color = { 0, 0, 0, 0, };
 	GdkColor *pcolor;
-	gboolean color_changed;
 
 	gboolean needs_update = 0;
 	gboolean needs_reflow = 0;
@@ -701,8 +622,6 @@ e_text_set_property (GObject *object,
 	item = GNOME_CANVAS_ITEM (object);
 	text = E_TEXT (object);
 
-	color_changed = FALSE;
-
 	switch (prop_id) {
 	case PROP_MODEL:
 
@@ -781,12 +700,6 @@ e_text_set_property (GObject *object,
 		needs_update = 1;
 		break;
 
-	case PROP_ANCHOR:
-		text->anchor = g_value_get_enum (value);
-		text->needs_recalc_bounds = 1;
-		needs_update = 1;
-		break;
-
 	case PROP_JUSTIFICATION:
 		text->justification = g_value_get_enum (value);
 		text->needs_redraw = 1;
@@ -855,7 +768,8 @@ e_text_set_property (GObject *object,
 			      (color.green & 0xff00) << 8 |
 			      (color.blue & 0xff00) |
 			      0xff);
-		color_changed = TRUE;
+		text->needs_redraw = 1;
+		needs_update = 1;
 		break;
 
 	case PROP_FILL_COLOR_GDK:
@@ -868,7 +782,8 @@ e_text_set_property (GObject *object,
 			      (color.green & 0xff00) << 8 |
 			      (color.blue & 0xff00) |
 			      0xff);
-		color_changed = TRUE;
+		text->needs_redraw = 1;
+		needs_update = 1;
 		break;
 
         case PROP_FILL_COLOR_RGBA:
@@ -876,11 +791,6 @@ e_text_set_property (GObject *object,
 		color.red = ((text->rgba >> 24) & 0xff) * 0x101;
 		color.green = ((text->rgba >> 16) & 0xff) * 0x101;
 		color.blue = ((text->rgba >> 8) & 0xff) * 0x101;
-		color_changed = TRUE;
-		break;
-
-	case PROP_FILL_STIPPLE:
-		set_stipple (text, g_value_get_object (value), FALSE);
 		text->needs_redraw = 1;
 		needs_update = 1;
 		break;
@@ -1014,20 +924,6 @@ e_text_set_property (GObject *object,
 		return;
 	}
 
-	if (color_changed) {
-               GdkColormap *colormap = gtk_widget_get_colormap (
-			GTK_WIDGET (item->canvas));
-
-	       text->color = color;
-               gdk_rgb_find_color (colormap, &text->color);
-
-	       if (!item->canvas->aa)
-		       set_text_gc_foreground (text);
-
-	       text->needs_redraw = 1;
-	       needs_update = 1;
-	}
-
 	if (needs_reflow)
 		e_canvas_item_request_reflow (item);
 	if (needs_update)
@@ -1056,7 +952,7 @@ e_text_get_property (GObject *object,
 		break;
 
 	case PROP_TEXT:
-		g_value_set_string (value, g_strdup (text->text));
+		g_value_set_string (value, text->text);
 		break;
 
 	case PROP_BOLD:
@@ -1067,10 +963,6 @@ e_text_get_property (GObject *object,
 		g_value_set_boolean (value, text->strikeout);
 		break;
 
-	case PROP_ANCHOR:
-		g_value_set_enum (value, text->anchor);
-		break;
-
 	case PROP_JUSTIFICATION:
 		g_value_set_enum (value, text->justification);
 		break;
@@ -1099,18 +991,10 @@ e_text_get_property (GObject *object,
 		g_value_set_double (value, text->yofs);
 		break;
 
-	case PROP_FILL_COLOR_GDK:
-		g_value_set_boxed (value, &text->color);
-		break;
-
 	case PROP_FILL_COLOR_RGBA:
 		g_value_set_uint (value, text->rgba);
 		break;
 
-	case PROP_FILL_STIPPLE:
-		g_value_set_object (value, text->stipple);
-		break;
-
 	case PROP_TEXT_WIDTH:
 		g_value_set_double (value, text->width / text->item.canvas->pixels_per_unit);
 		break;
@@ -1128,7 +1012,7 @@ e_text_get_property (GObject *object,
 		break;
 
 	case PROP_ELLIPSIS:
-		g_value_set_string (value, g_strdup (text->ellipsis));
+		g_value_set_string (value, text->ellipsis);
 		break;
 
 	case PROP_LINE_WRAP:
@@ -1136,7 +1020,7 @@ e_text_get_property (GObject *object,
 		break;
 
 	case PROP_BREAK_CHARACTERS:
-		g_value_set_string (value, g_strdup (text->break_characters));
+		g_value_set_string (value, text->break_characters);
 		break;
 
 	case PROP_MAX_LINES:
@@ -1220,7 +1104,7 @@ e_text_reflow (GnomeCanvasItem *item, gint flags)
 
 /* Update handler for the text item */
 static void
-e_text_update (GnomeCanvasItem *item, gdouble *affine, ArtSVP *clip_path, gint flags)
+e_text_update (GnomeCanvasItem *item, const cairo_matrix_t *i2c, gint flags)
 {
 	EText *text;
 	gdouble x1, y1, x2, y2;
@@ -1229,29 +1113,25 @@ e_text_update (GnomeCanvasItem *item, gdouble *affine, ArtSVP *clip_path, gint f
 
 	if (GNOME_CANVAS_ITEM_CLASS (e_text_parent_class)->update)
 		GNOME_CANVAS_ITEM_CLASS (e_text_parent_class)->update (
-			item, affine, clip_path, flags);
+			item, i2c, flags);
 
 	if ( text->needs_recalc_bounds
 	     || (flags & GNOME_CANVAS_UPDATE_AFFINE)) {
-		if (!item->canvas->aa) {
-			set_text_gc_foreground (text);
-			set_stipple (text, text->stipple, TRUE);
-			get_bounds (text, &x1, &y1, &x2, &y2);
-			if ( item->x1 != x1 ||
-			     item->x2 != x2 ||
-			     item->y1 != y1 ||
-			     item->y2 != y2 ) {
-				gnome_canvas_request_redraw (item->canvas, item->x1, item->y1, item->x2, item->y2);
-				item->x1 = x1;
-				item->y1 = y1;
-				item->x2 = x2;
-				item->y2 = y2;
-				text->needs_redraw = 1;
-				item->canvas->need_repick = TRUE;
-			}
-			if (!text->fill_clip_rectangle)
-				item->canvas->need_repick = TRUE;
-		}
+                get_bounds (text, &x1, &y1, &x2, &y2);
+                if ( item->x1 != x1 ||
+                     item->x2 != x2 ||
+                     item->y1 != y1 ||
+                     item->y2 != y2 ) {
+                        gnome_canvas_request_redraw (item->canvas, item->x1, item->y1, item->x2, item->y2);
+                        item->x1 = x1;
+                        item->y1 = y1;
+                        item->x2 = x2;
+                        item->y2 = y2;
+                        text->needs_redraw = 1;
+                        item->canvas->need_repick = TRUE;
+                }
+                if (!text->fill_clip_rectangle)
+                        item->canvas->need_repick = TRUE;
 		text->needs_recalc_bounds = 0;
 	}
 	if (text->needs_redraw) {
@@ -1265,7 +1145,6 @@ static void
 e_text_realize (GnomeCanvasItem *item)
 {
 	EText *text;
-	GdkWindow *bin_window;
 
 	text = E_TEXT (item);
 
@@ -1274,15 +1153,6 @@ e_text_realize (GnomeCanvasItem *item)
 
 	create_layout (text);
 
-	bin_window = gtk_layout_get_bin_window (GTK_LAYOUT (item->canvas));
-	text->gc = gdk_gc_new (bin_window);
-
-/* FIXME: Color brokenness ... */
-#if 0
-	gdk_color_context_query_color (item->canvas->cc, &text->color);
-	gdk_gc_set_foreground (text->gc, &text->color);
-#endif
-
 	text->i_cursor = gdk_cursor_new (GDK_XTERM);
 	text->default_cursor = gdk_cursor_new (GDK_LEFT_PTR);
 }
@@ -1295,9 +1165,6 @@ e_text_unrealize (GnomeCanvasItem *item)
 
 	text = E_TEXT (item);
 
-	g_object_unref (text->gc);
-	text->gc = NULL;
-
 	gdk_cursor_unref (text->i_cursor);
 	text->i_cursor = NULL;
 	gdk_cursor_unref (text->default_cursor);
@@ -1322,7 +1189,7 @@ _get_tep (EText *text)
 
 static void
 draw_pango_rectangle (GdkDrawable *drawable,
-                      GdkGC *gc,
+                      cairo_t *cr,
                       gint x1,
                       gint y1,
                       PangoRectangle rect)
@@ -1333,8 +1200,8 @@ draw_pango_rectangle (GdkDrawable *drawable,
 		width = 1;
 	if (height <= 0)
 		height = 1;
-	gdk_draw_rectangle (drawable, gc, TRUE,
-			    x1 + rect.x / PANGO_SCALE, y1 + rect.y / PANGO_SCALE, width, height);
+	cairo_rectangle (cr, x1 + rect.x / PANGO_SCALE, y1 + rect.y / PANGO_SCALE, width, height);
+        cairo_fill (cr);
 }
 
 static gboolean
@@ -1407,9 +1274,8 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 	     gint x, gint y, gint width, gint height)
 {
 	EText *text;
-	GdkRectangle rect, *clip_rect;
 	gint xpos, ypos;
-	GdkGC *main_gc;
+	cairo_t *cr;
 	GnomeCanvas *canvas;
 	GtkWidget *widget;
 	GdkWindow *window;
@@ -1422,11 +1288,16 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 	state = gtk_widget_get_state (widget);
 	style = gtk_widget_get_style (widget);
 	window = gtk_widget_get_window (widget);
+        cr = gdk_cairo_create (drawable);
 
 	if (text->draw_background || text->draw_button) {
-		main_gc = style->fg_gc[state];
+		gdk_cairo_set_source_color (cr, &style->fg[state]);
 	} else {
-		main_gc = text->gc;
+                cairo_set_source_rgba (cr,
+                                       ((text->rgba >> 24) & 0xff) / 255.0,
+                                       ((text->rgba >> 16) & 0xff) / 255.0,
+                                       ((text->rgba >>  8) & 0xff) / 255.0,
+                                       ( text->rgba        & 0xff) / 255.0);
 	}
 
 	if (text->draw_borders || text->draw_background) {
@@ -1572,11 +1443,10 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 	if (!text->preedit_len)
 		reset_layout (text);
 
-	if (!pango_layout_get_text (text->layout))
+	if (!pango_layout_get_text (text->layout)) {
+		cairo_destroy (cr);
 		return;
-
-	if (text->stipple)
-		gnome_canvas_set_stipple_origin (item->canvas, main_gc);
+	}
 
 	xpos = text->text_cx;
 	ypos = text->text_cy;
@@ -1584,15 +1454,12 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 	xpos = xpos - x + text->xofs;
 	ypos = ypos - y + text->yofs;
 
-	clip_rect = NULL;
 	if (text->clip) {
-		rect.x = xpos;
-		rect.y = ypos;
-		rect.width = text->clip_cwidth - text->xofs;
-		rect.height = text->clip_cheight - text->yofs;
-
-		gdk_gc_set_clip_rectangle (main_gc, &rect);
-		clip_rect = &rect;
+                cairo_rectangle (cr,
+                                 xpos, ypos,
+                                 text->clip_cwidth - text->xofs,
+                                 text->clip_cheight - text->yofs);
+                cairo_clip (cr);
 	}
 
 	if (text->editing) {
@@ -1600,95 +1467,37 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 		ypos -= text->yofs_edit;
 	}
 
-	gdk_draw_layout (drawable, main_gc,
-			 xpos, ypos,
-			 text->layout);
+        cairo_move_to (cr, xpos, ypos);
+        pango_cairo_show_layout (cr, text->layout);
 
 	if (text->editing) {
 		if (text->selection_start != text->selection_end) {
-			PangoLayoutIter *iter;
 			GdkRegion *clip_region = gdk_region_new ();
-			GdkGC *selection_gc;
-			GdkGC *text_gc;
-			gint start_index, end_index;
+			gint indices[2];
+                        GtkStateType state;
 
-			start_index = MIN (text->selection_start, text->selection_end);
-			end_index = MAX (text->selection_start, text->selection_end);
+                        state = text->has_selection ? GTK_STATE_SELECTED : GTK_STATE_ACTIVE;
+
+			indices[0] = MIN (text->selection_start, text->selection_end);
+			indices[1] = MAX (text->selection_start, text->selection_end);
 
 			/* convert these into byte indices */
-			start_index = g_utf8_offset_to_pointer (text->text, start_index) - text->text;
-			end_index = g_utf8_offset_to_pointer (text->text, end_index) - text->text;
-
-			if (text->has_selection) {
-				selection_gc = style->base_gc[GTK_STATE_SELECTED];
-				text_gc = style->text_gc[GTK_STATE_SELECTED];
-			} else {
-				selection_gc = style->base_gc[GTK_STATE_ACTIVE];
-				text_gc = style->text_gc[GTK_STATE_ACTIVE];
-			}
-
-			gdk_gc_set_clip_rectangle (selection_gc, clip_rect);
-
-			iter = pango_layout_get_iter (text->layout);
-
-			do {
-				PangoLayoutLine *line = pango_layout_iter_get_line (iter);
-				gint n_ranges, i;
-				gint *ranges;
-				gint y0, y1;
-				gint s, e;
-
-				if (start_index < line->start_index + line->length
-				    && end_index > line->start_index) {
-
-					if (start_index <= line->start_index)
-						s = line->start_index;
-					else
-						s = start_index;
-
-					if (end_index > line->start_index + line->length)
-						e = line->start_index + line->length;
-					else
-						e = end_index;
-
-					pango_layout_line_get_x_ranges (line, s, e, &ranges, &n_ranges);
-
-					pango_layout_iter_get_line_yrange (iter, &y0, &y1);
-
-					for (i=0; i < n_ranges; i++) {
-						GdkRectangle sel_rect;
-
-						sel_rect.x = xpos + PANGO_PIXELS (ranges[2*i]);
-						sel_rect.y = ypos + PANGO_PIXELS (y0);
-						sel_rect.width = (ranges[2*i + 1] - ranges[2*i]) / PANGO_SCALE;
-						sel_rect.height = (y1 - y0 + PANGO_SCALE / 2) / PANGO_SCALE;
-
-						gdk_draw_rectangle (drawable, selection_gc, TRUE,
-								    sel_rect.x, sel_rect.y, sel_rect.width, sel_rect.height);
-
-						gdk_region_union_with_rect (clip_region, &sel_rect);
-					}
-					g_free (ranges);
-				}
-			} while (pango_layout_iter_next_line (iter));
-
-			pango_layout_iter_free (iter);
-
-			if (clip_rect) {
-				GdkRegion *rect_region = gdk_region_rectangle (clip_rect);
-				gdk_region_intersect (clip_region, rect_region);
-				gdk_region_destroy (rect_region);
-			}
-
-			gdk_gc_set_clip_region (text_gc, clip_region);
-			gdk_draw_layout (drawable, text_gc,
-					 xpos, ypos,
-					 text->layout);
-
-			gdk_gc_set_clip_region (text_gc, NULL);
-			gdk_gc_set_clip_region (selection_gc, NULL);
+			indices[0] = g_utf8_offset_to_pointer (text->text, indices[0]) - text->text;
+			indices[1] = g_utf8_offset_to_pointer (text->text, indices[1]) - text->text;
 
+                        clip_region = gdk_pango_layout_get_clip_region (text->layout,
+                                                                        xpos, ypos,
+                                                                        indices, 1);
+                        gdk_cairo_region (cr, clip_region);
+                        cairo_clip (cr);
 			gdk_region_destroy (clip_region);
+
+                        gdk_cairo_set_source_color (cr, &style->base[state]);
+                        cairo_paint (cr);
+
+                        gdk_cairo_set_source_color (cr, &style->text[state]);
+                        cairo_move_to (cr, xpos, ypos);
+                        pango_cairo_show_layout (cr, text->layout);
 		} else {
 			if (text->show_cursor) {
 				PangoRectangle strong_pos, weak_pos;
@@ -1698,25 +1507,23 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 					text->layout, offs - text->text +
 					text->preedit_len, &strong_pos,
 					&weak_pos);
-				draw_pango_rectangle (drawable, main_gc, xpos, ypos, strong_pos);
+				draw_pango_rectangle (drawable, cr, xpos, ypos, strong_pos);
 				if (strong_pos.x != weak_pos.x ||
 				    strong_pos.y != weak_pos.y ||
 				    strong_pos.width != weak_pos.width ||
 				    strong_pos.height != weak_pos.height)
-					draw_pango_rectangle (drawable, main_gc, xpos, ypos, weak_pos);
+					draw_pango_rectangle (drawable, cr, xpos, ypos, weak_pos);
 			}
 		}
 	}
 
-	if (text->clip) {
-		gdk_gc_set_clip_rectangle (main_gc, NULL);
-	}
+	cairo_destroy (cr);
 }
 
 /* Point handler for the text item */
-static double
+static GnomeCanvasItem *
 e_text_point (GnomeCanvasItem *item, gdouble x, gdouble y,
-	      gint cx, gint cy, GnomeCanvasItem **actual_item)
+	      gint cx, gint cy)
 {
 	EText *text;
 	gdouble clip_width;
@@ -1724,8 +1531,6 @@ e_text_point (GnomeCanvasItem *item, gdouble x, gdouble y,
 
 	text = E_TEXT (item);
 
-	*actual_item = item;
-
 	/* The idea is to build bounding rectangles for each of the lines of
 	 * text (clipped by the clipping rectangle, if it is activated) and see
 	 * whether the point is inside any of these.  If it is, we are done.
@@ -1750,17 +1555,17 @@ e_text_point (GnomeCanvasItem *item, gdouble x, gdouble y,
 	    cx > text->clip_cx + clip_width ||
 	    cy < text->clip_cy ||
 	    cy > text->clip_cy + clip_height)
-		return 1;
+		return NULL;
 
 	if (text->fill_clip_rectangle || !text->text || !*text->text)
-		return 0;
+		return item;
 
 	cx -= text->cx;
 
 	if (pango_layout_xy_to_index (text->layout, cx, cy, NULL, NULL))
-		return 0;
+		return item;
 
-	return 1;
+	return NULL;
 }
 
 /* Bounds handler for the text item */
@@ -1792,44 +1597,6 @@ e_text_bounds (GnomeCanvasItem *item,
 	width = width / item->canvas->pixels_per_unit;
 	height = height / item->canvas->pixels_per_unit;
 
-	switch (text->anchor) {
-	case GTK_ANCHOR_NW:
-	case GTK_ANCHOR_W:
-	case GTK_ANCHOR_SW:
-		break;
-
-	case GTK_ANCHOR_N:
-	case GTK_ANCHOR_CENTER:
-	case GTK_ANCHOR_S:
-		*x1 -= width / 2.0;
-		break;
-
-	case GTK_ANCHOR_NE:
-	case GTK_ANCHOR_E:
-	case GTK_ANCHOR_SE:
-		*x1 -= width;
-		break;
-	}
-
-	switch (text->anchor) {
-	case GTK_ANCHOR_NW:
-	case GTK_ANCHOR_N:
-	case GTK_ANCHOR_NE:
-		break;
-
-	case GTK_ANCHOR_W:
-	case GTK_ANCHOR_CENTER:
-	case GTK_ANCHOR_E:
-		*y1 -= height / 2.0;
-		break;
-
-	case GTK_ANCHOR_SW:
-	case GTK_ANCHOR_S:
-	case GTK_ANCHOR_SE:
-		*y1 -= height;
-		break;
-	}
-
 	*x2 = *x1 + width;
 	*y2 = *y1 + height;
 }
@@ -2113,7 +1880,7 @@ e_text_event (GnomeCanvasItem *item, GdkEvent *event)
 
 		/* Handle S-F10 key binding here. */
 
-		if (event->key.keyval == GDK_F10
+		if (event->key.keyval == GDK_KEY_F10
 		    && (event->key.state & GDK_SHIFT_MASK)
 		    && text->handle_popup ) {
 
@@ -3034,12 +2801,16 @@ e_text_insert (EText *text, const gchar *string)
 				}
 			}
 			*j = 0;
-			e_text_model_insert_length (text->model, text->selection_start, new_string, utf8len);
+			e_text_model_insert_length (
+				text->model, text->selection_start,
+				new_string, utf8len);
 			g_free (new_string);
 		}
 		else {
 			utf8len = g_utf8_strlen (string, -1);
-			e_text_model_insert_length (text->model, text->selection_start, string, utf8len);
+			e_text_model_insert_length (
+				text->model, text->selection_start,
+				string, utf8len);
 		}
 	}
 }
@@ -3410,13 +3181,6 @@ e_text_class_init (ETextClass *klass)
 							       FALSE,
 							       G_PARAM_READWRITE));
 
-	g_object_class_install_property (gobject_class, PROP_ANCHOR,
-					 g_param_spec_enum ("anchor",
-							    "Anchor",
-							    "Anchor",
-							    GTK_TYPE_ANCHOR_TYPE, GTK_ANCHOR_CENTER,
-							    G_PARAM_READWRITE));
-
 	g_object_class_install_property (gobject_class, PROP_JUSTIFICATION,
 					 g_param_spec_enum ("justification",
 							    "Justification",
@@ -3471,14 +3235,14 @@ e_text_class_init (ETextClass *klass)
 							      "Fill color",
 							      "Fill color",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_WRITABLE));
 
 	g_object_class_install_property (gobject_class, PROP_FILL_COLOR_GDK,
 					 g_param_spec_boxed ("fill_color_gdk",
 							     "GDK fill color",
 							     "GDK fill color",
 							     GDK_TYPE_COLOR,
-							     G_PARAM_READWRITE));
+							     G_PARAM_WRITABLE));
 
 	g_object_class_install_property (gobject_class, PROP_FILL_COLOR_RGBA,
 					 g_param_spec_uint ("fill_color_rgba",
@@ -3487,13 +3251,6 @@ e_text_class_init (ETextClass *klass)
 							    0, G_MAXUINT, 0,
 							    G_PARAM_READWRITE));
 
-	g_object_class_install_property (gobject_class, PROP_FILL_STIPPLE,
-					 g_param_spec_object ("fill_stipple",
-							      "Fill stipple",
-							      "Fill stipple",
-							      GDK_TYPE_DRAWABLE,
-							      G_PARAM_READWRITE));
-
 	g_object_class_install_property (gobject_class, PROP_TEXT_WIDTH,
 					 g_param_spec_double ("text_width",
 							      "Text width",
@@ -3642,7 +3399,6 @@ e_text_init (EText *text)
 				  G_CALLBACK (e_text_text_model_reposition),
 				  text);
 
-	text->anchor                  = GTK_ANCHOR_CENTER;
 	text->justification           = GTK_JUSTIFY_LEFT;
 	text->clip_width              = -1.0;
 	text->clip_height             = -1.0;
